@@ -2,7 +2,7 @@
  *
  * $Id: classdef.h,v 1.39 2001/03/19 19:27:39 root Exp $
  *
- * Copyright (C) 1997-2004 by Dimitri van Heesch.
+ * Copyright (C) 1997-2005 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -67,7 +67,7 @@ class ClassDef : public Definition
                         Category=Entry::CATEGORY_SEC,
                         Exception=Entry::EXCEPTION_SEC
                       };
-    DefType definitionType() { return TypeClass; }
+    DefType definitionType() const { return TypeClass; }
     QCString getOutputFileBase() const; 
     QCString getInstanceOutputFileBase() const; 
     QCString getFileBase() const;
@@ -104,9 +104,12 @@ class ClassDef : public Definition
 
     void writeDocumentation(OutputList &ol);
     void writeDocumentationForInnerClasses(OutputList &ol);
+    void writeMemberDocumentation(OutputList &ol);
+    void writeMemberPages(OutputList &ol);
     void writeMemberList(OutputList &ol);
     void writeDeclaration(OutputList &ol,MemberDef *md,bool inGroup);
     void writeDetailedDescription(OutputList &ol,const QCString &pageType,bool exampleFlag);
+    void writeQuickMemberLinks(OutputList &ol,MemberDef *md) const;
 
     /*! Return the protection level (Public,Protected,Private) in which 
      *  this compound was found.
@@ -302,6 +305,7 @@ class ClassDef : public Definition
     void setIsStatic(bool b) { m_isStatic=b; }
     void setIsObjectiveC(bool b) { m_isObjC=b; }
     void addListReferences();
+    void setCompoundType(CompoundType t) { m_compType = t; } 
 
     /*! Creates a new compound definition.
      *  \param fileName  full path and file name in which this compound was
