@@ -2,7 +2,7 @@
  *
  * $Id: commentcnv.l,v 1.80 2001/03/19 19:27:41 root Exp $
  *
- * Copyright (C) 1997-2004 by Dimitri van Heesch.
+ * Copyright (C) 1997-2005 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -20,7 +20,8 @@
 
 class BufStr;
 
-extern void convertCppComments(BufStr *inBuf,BufStr *outBuf);
+extern void convertCppComments(BufStr *inBuf,BufStr *outBuf,
+                               const char *fileName);
 
 #endif
 
