@@ -32,6 +32,7 @@
 #include "pagedef.h"
 #include "section.h"
 #include "htags.h"
+#include "parserintf.h"
 
 #if defined(_MSC_VER) || defined(__BORLANDC__)
 #define popen _popen
@@ -81,6 +82,11 @@ Definition::Definition(const char *df,int dl,
 {
   //QCString ns;
   m_defFileName = df;
+  int lastDot = m_defFileName.findRev('.');
+  if (lastDot!=-1)
+  {
+    m_defFileExt = m_defFileName.mid(lastDot);
+  }
   m_defLine = dl;
   m_name=name; 
   if (m_name!="<globalScope>") 
@@ -221,10 +227,15 @@ void Definition::setDocumentation(const char *d,const char *docFile,int docLine,
 void Definition::setBriefDescription(const char *b,const char *briefFile,int briefLine) 
 { 
   if (b==0) return;
+  static QCString outputLanguage = Config_getEnum("OUTPUT_LANGUAGE");
+  static bool needsDot = outputLanguage!="Japanese" && 
+                         outputLanguage!="Chinese" &&
+                         outputLanguage!="Korean";
+
   //fprintf(stderr,"Definition::setBriefDescription(%s,%s,%d)\n",b,briefFile,briefLine);
   m_brief=QCString(b).stripWhiteSpace();
   int bl=m_brief.length(); 
-  if (bl>0) // add punctuation if needed
+  if (bl>0 && needsDot) // add punctuation if needed
   {
     switch(m_brief.at(bl-1))
     {
@@ -253,7 +264,7 @@ static bool readCodeFragment(const char *fileName,
 {
   //printf("readCodeFragment(%s,%d,%d)\n",fileName,startLine,endLine);
   if (fileName==0 || fileName[0]==0) return FALSE; // not a valid file name
-  QCString cmd="\"" + getFileFilter(fileName)+"\" \""+fileName+"\"";
+  QCString cmd=getFileFilter(fileName)+" \""+fileName+"\"";
   FILE *f = Config_getBool("FILTER_SOURCE_FILES") ? popen(cmd,"r") : fopen(fileName,"r");
   bool found=FALSE;
   if (f)
@@ -459,12 +470,23 @@ void Definition::writeInlineCode(OutputList &ol,const char *scopeName)
           actualStart,actualEnd,codeFragment)
        )
     {
-      initParseCodeContext();
+      ParserInterface *pIntf = Doxygen::parserManager->getParser(m_defFileExt);
+      pIntf->resetCodeParserState();
       //printf("Read:\n`%s'\n\n",codeFragment.data());
-      if (definitionType()==TypeMember) setParameterList((MemberDef *)this);
+      MemberDef *thisMd = 0;
+      if (definitionType()==TypeMember) thisMd = (MemberDef *)this;
       ol.startCodeFragment();
-      parseCode(ol,scopeName,codeFragment,FALSE,0,
-          m_bodyDef,actualStart,actualEnd,TRUE);
+      pIntf->parseCode(ol,           // codeOutIntf
+                       scopeName,    // scope
+                       codeFragment, // input
+                       FALSE,        // isExample
+                       0,            // exampleName
+                       m_bodyDef,    // fileDef
+                       actualStart,  // startLine
+                       actualEnd,    // endLine
+                       TRUE,         // inlineFragment
+                       thisMd        // memberDef
+                      );
       ol.endCodeFragment();
       ol.newParagraph();
     }
