@@ -2,7 +2,7 @@
  *
  * $Id: entry.h,v 1.36 2001/03/19 19:27:40 root Exp $
  *
- * Copyright (C) 1997-2004 by Dimitri van Heesch.
+ * Copyright (C) 1997-2005 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -87,6 +87,7 @@ struct Argument
   
   QCString attrib;   /*!< Argument's attribute (IDL only) */
   QCString type;     /*!< Argument's type */
+  QCString canType;  /*!< Cached value of canonical type (after type resolution). Empty initially. */
   QCString name;     /*!< Argument's name (may be empty) */
   QCString array;    /*!< Argument's array specifier (may be empty) */
   QCString defval;   /*!< Argument's default value (may be empty) */
@@ -320,9 +321,9 @@ class Entry
     {
       switch( groupDocType ) 
       {
-        case GROUPDOC_NORMAL: return "\\defgroup"; break;
-        case GROUPDOC_ADD: return "\\addgroup"; break;
-        case GROUPDOC_WEAK: return "\\weakgroup"; break;
+        case GROUPDOC_NORMAL: return "\\defgroup";
+        case GROUPDOC_ADD: return "\\addgroup";
+        case GROUPDOC_WEAK: return "\\weakgroup";
         default: return "unknown group command";
       }
     }
@@ -334,9 +335,9 @@ class Entry
       }
       switch( groupDocType ) 
       {
-        case GROUPDOC_NORMAL: return Grouping::GROUPING_AUTO_DEF;  break;
-        case GROUPDOC_ADD:    return Grouping::GROUPING_AUTO_ADD;  break;
-        case GROUPDOC_WEAK:   return Grouping::GROUPING_AUTO_WEAK; break;
+        case GROUPDOC_NORMAL: return Grouping::GROUPING_AUTO_DEF;
+        case GROUPDOC_ADD:    return Grouping::GROUPING_AUTO_ADD;
+        case GROUPDOC_WEAK:   return Grouping::GROUPING_AUTO_WEAK;
         default: return Grouping::GROUPING_LOWEST;
       }
     }
