@@ -28,18 +28,18 @@
 #include "outputlist.h"
 #include "dot.h"
 #include "message.h"
-#include "code.h"
 #include "docparser.h"
 #include "ftvhelp.h"
 #include "searchindex.h"
 #include "htags.h"
+#include "parserintf.h"
 
 #if defined(_MSC_VER) || defined(__BORLANDC__)
 #define popen _popen
 #define pclose _pclose
 #endif
 
-class DevNullCodeDocInterface : public BaseCodeDocInterface
+class DevNullCodeDocInterface : public CodeOutputInterface
 {
   public:
     virtual void codify(const char *) {}
@@ -653,9 +653,10 @@ void FileDef::writeSource(OutputList &ol)
     ol.endTextLink();
   }
 
-  initParseCodeContext();
+  ParserInterface *pIntf = Doxygen::parserManager->getParser(getDefFileExtension());
+  pIntf->resetCodeParserState();
   ol.startCodeFragment();
-  parseCode(ol,0,
+  pIntf->parseCode(ol,0,
             fileToString(absFilePath(),Config_getBool("FILTER_SOURCE_FILES")),
             FALSE,0,this
            );
@@ -667,7 +668,10 @@ void FileDef::writeSource(OutputList &ol)
 void FileDef::parseSource()
 {
   DevNullCodeDocInterface devNullIntf;
-  parseCode(devNullIntf,0,
+  ParserInterface *pIntf = Doxygen::parserManager->getParser(getDefFileExtension());
+  pIntf->resetCodeParserState();
+  pIntf->parseCode(
+            devNullIntf,0,
             fileToString(absFilePath(),Config_getBool("FILTER_SOURCE_FILES")),
             FALSE,0,this
            );
@@ -686,13 +690,17 @@ void FileDef::addMembersToMemberGroup()
 /*! Adds member definition \a md to the list of all members of this file */
 void FileDef::insertMember(MemberDef *md)
 {
-  //printf("%s:FileDef::insertMember(%s)\n",name().data(),md->name().data());
-  if (allMemberList.find(md)!=-1) return;
+  //printf("%s:FileDef::insertMember(%s (=%p) list has %d elements)\n",
+  //    name().data(),md->name().data(),md,allMemberList.count());
+  if (allMemberList.findRef(md)!=-1) 
+  { 
+    return;
+  }
 
   allMemberList.append(md); 
   bool sortBriefDocs = Config_getBool("SORT_BRIEF_DOCS");
   bool sortMemberDocs = Config_getBool("SORT_MEMBER_DOCS");
-  switch(md->memberType())
+  switch (md->memberType())
   {
     case MemberDef::Variable:     
     case MemberDef::Property:     
@@ -754,6 +762,7 @@ void FileDef::insertNamespace(NamespaceDef *nd)
 
 void FileDef::addSourceRef(int line,Definition *d,MemberDef *md)
 {
+  //printf("FileDef::addSourceDef(%d,%p,%p)\n",line,d,md);
   if (d)
   {
     if (srcDefDict==0)    srcDefDict    = new QIntDict<Definition>(257);
@@ -1129,7 +1138,7 @@ static void addDirsAsGroups(Directory *root,GroupDef *parent,int level)
   GroupDef *gd=0;
   if (root->kind()==DirEntry::Dir)
   {
-    gd = new GroupDef("<generated>",
+    gd = new GroupDef("[generated]",
                       1,
                       root->path(), // name
                       root->name()  // title
