@@ -2,7 +2,7 @@
  *
  * $Id: filedef.h,v 1.32 2001/03/19 19:27:40 root Exp $
  *
- * Copyright (C) 1997-2004 by Dimitri van Heesch.
+ * Copyright (C) 1997-2005 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -69,7 +69,7 @@ class FileDef : public Definition
 
     FileDef(const char *p,const char *n,const char *ref=0,const char *dn=0);
    ~FileDef();
-    DefType definitionType() { return TypeFile; }
+    DefType definitionType() const { return TypeFile; }
 
     /*! Returns the unique file name (this may include part of the path). */
     QCString name() const 
@@ -86,12 +86,10 @@ class FileDef : public Definition
     QCString getFileBase() const
     { return diskname; }
 
-    QCString getSourceFileBase() const
-    { return convertNameToFile(diskname+"-source"); }
+    QCString getSourceFileBase() const;
     
     /*! Returns the name of the verbatim copy of this file (if any). */
-    QCString includeName() const 
-    { return convertNameToFile(diskname+"-source"); }
+    QCString includeName() const;
     
     /*! Returns the absolute path including the file name. */
     QCString absFilePath() const { return filepath; }
@@ -126,6 +124,10 @@ class FileDef : public Definition
 
     void writeDetailedDocumentation(OutputList &ol);
     void writeDocumentation(OutputList &ol);
+    void writeMemberDocumentation(OutputList &ol);
+    void writeMemberPages(OutputList &ol);
+    void writeQuickMemberLinks(OutputList &ol,MemberDef *currentMd) const;
+
     void writeSource(OutputList &ol);
     void parseSource();
     friend void generatedFileNames();
@@ -174,7 +176,7 @@ class FileDef : public Definition
     MemberList decFuncMembers;
     MemberList decVarMembers;
 
-    // members in the documentation part of the documentation
+    // members in the detailed part of the documentation
     MemberList docDefineMembers;
     MemberList docProtoMembers;
     MemberList docTypedefMembers;
