@@ -2,7 +2,7 @@
  *
  * $Id: groupdef.h,v 1.18 2001/03/19 19:27:40 root Exp $
  *
- * Copyright (C) 1997-2004 by Dimitri van Heesch.
+ * Copyright (C) 1997-2005 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -32,18 +32,20 @@ class ClassDef;
 class NamespaceDef;
 class GroupList;
 class OutputList;
-class NamespaceList;
+class NamespaceSDict;
 class MemberGroupSDict;
 class MemberNameInfoSDict;
 class PageSDict;
 class PageDef;
+class DirDef;
+class DirList;
 
 class GroupDef : public Definition
 {
   public:
     GroupDef(const char *fileName,int line,const char *name,const char *title,const char *refFileName=0);
    ~GroupDef();
-    DefType definitionType() { return TypeGroup; }
+    DefType definitionType() const { return TypeGroup; }
     QCString getOutputFileBase() const;
     const char *groupTitle() const { return title; }
     void setGroupTitle( const char *newtitle );
@@ -53,13 +55,17 @@ class GroupDef : public Definition
     void addNamespace(const NamespaceDef *def);
     void addGroup(const GroupDef *def);
     void addParentGroup(const GroupDef *def);
-    void addPage(PageDef *def);                // pages in this group
-    void addExample(const PageDef *def);       // examples in this group
+    void addPage(PageDef *def);
+    void addExample(const PageDef *def);
+    void addDir(const DirDef *dd);
     bool insertMember(MemberDef *def,bool docOnly=FALSE);
     void removeMember(MemberDef *md);
     bool containsGroup(const GroupDef *def);    // true if def is already a subgroup
     void writeDetailedDocumentation(OutputList &ol);
     void writeDocumentation(OutputList &ol);
+    void writeMemberDocumentation(OutputList &ol);
+    void writeMemberPages(OutputList &ol);
+    void writeQuickMemberLinks(OutputList &ol,MemberDef *currentMd) const;
     int countMembers() const;
     bool isLinkableInProject() const
     {
@@ -105,24 +111,26 @@ class GroupDef : public Definition
 
     FileList *      getFiles() const        { return fileList; }
     ClassSDict *    getClasses() const      { return classSDict; }
-    NamespaceList * getNamespaces() const   { return namespaceList; }
+    NamespaceSDict * getNamespaces() const   { return namespaceSDict; }
     GroupList *     getSubGroups() const    { return groupList; }
     PageSDict *     getPages() const        { return pageDict; }
+    DirList *       getDirs() const         { return dirList; }
+    MemberList*     getMembers() const      { return allMemberList; }
     
   protected:
     void addMemberListToGroup(MemberList *,bool (MemberDef::*)() const);
 
   private: 
-    QCString title;                     // title of the group
-    bool titleSet;                      // true if title is not the same as the name
-    QCString fileName;                  // base name of the generated file
-    FileList *fileList;                 // list of files in the group
-    ClassSDict *classSDict;             // list of classes in the group
-    NamespaceList *namespaceList;       // list of namespaces in the group
-    GroupList *groupList;              // list of sub groups.
-    //GroupList *parentGroupList;        // list of parent groups.
-    PageSDict *pageDict;                // list of pages in the group
-    PageSDict *exampleDict;             // list of examples in the group
+    QCString title;                      // title of the group
+    bool titleSet;                       // true if title is not the same as the name
+    QCString fileName;                   // base name of the generated file
+    FileList *fileList;                  // list of files in the group
+    ClassSDict *classSDict;              // list of classes in the group
+    NamespaceSDict *namespaceSDict;      // list of namespaces in the group
+    GroupList *groupList;                // list of sub groups.
+    PageSDict *pageDict;                 // list of pages in the group
+    PageSDict *exampleDict;              // list of examples in the group
+    DirList *dirList;                    // list of directories in the group
 
     MemberList *allMemberList;
     MemberNameInfoSDict *allMemberNameInfoSDict;
@@ -154,6 +162,7 @@ void addGroupToGroups(Entry *root,GroupDef *subGroup);
 void addMemberToGroups(Entry *root,MemberDef *md);
 void addPageToGroups(Entry *root,PageDef *pd);
 void addExampleToGroups(Entry *root,PageDef *eg);
+void addDirToGroups(Entry *root,DirDef *dd);
 
 #endif
 
