@@ -603,9 +603,13 @@ void HtmlGenerator::startDoxyAnchor(const char *,const char *,
                                     const char *args)
 {
   t << "<a class=\"anchor\" name=\"" << anchor << "\"></a>";
-  t << "<!-- doxytag: member=<" << name << "> ref=<" << anchor << "> args=<";
+  t << "<!-- doxytag: member=\"";
+  docify(name); 
+  t << "\" ref=\""; 
+  docify(anchor); 
+  t << "\" args=\"";
   docify(args);
-  t << "> -->";
+  t << "\" -->";
 }
 
 void HtmlGenerator::endDoxyAnchor(const char *,const char *)
@@ -815,6 +819,7 @@ void HtmlGenerator::docify(const char *str)
         case '<':  t << "&lt;"; break;
         case '>':  t << "&gt;"; break;
         case '&':  t << "&amp;"; break;
+        case '"':  t << "&quot;"; break;
         case '\\':
                    if (*p=='<')
                      { t << "&lt;"; p++; }
@@ -1413,9 +1418,9 @@ void HtmlGenerator::endParamList()
   t << "</dl>"; 
 }
 
-void HtmlGenerator::printDoc(DocNode *n)
+void HtmlGenerator::printDoc(DocNode *n,const char *langExt)
 {
-  HtmlDocVisitor *visitor = new HtmlDocVisitor(t,*this);
+  HtmlDocVisitor *visitor = new HtmlDocVisitor(t,*this,langExt);
   n->accept(visitor);
   delete visitor; 
 }
@@ -1636,6 +1641,12 @@ void HtmlGenerator::writeSearchPage()
       { 
         writeDefaultQuickLinks(t,TRUE,HLI_Search,"");
       }
+      else
+      {
+        t << "<div class=\"qindex\">\n";
+        t << "  <form class=\"search\" action=\"search.php\" "
+          << "method=\"get\">\n";
+      }
 
       t << "\n<?php\n\n";
       t << "function search_results()\n";
