@@ -2,7 +2,7 @@
  *
  * $Id: index.h,v 1.28 2001/03/19 19:27:40 root Exp $
  *
- * Copyright (C) 1997-2004 by Dimitri van Heesch.
+ * Copyright (C) 1997-2005 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -49,24 +49,28 @@ void writeIndex(OutputList &ol);
 void writeHierarchicalIndex(OutputList &ol);
 void writeAlphabeticalIndex(OutputList &ol);
 void writeClassHierarchy(OutputList &ol);
-void writeFileIndex(OutputList &ol);
-void writeSourceIndex(OutputList &ol);
 void writeAnnotatedIndex(OutputList &ol);
 void writeAnnotatedClassList(OutputList &ol);
-void writeMemberIndex(OutputList &ol);
 void writeMemberList(OutputList &ol,bool useSections);
+
+void writeSourceIndex(OutputList &ol);
 void writeHeaderIndex(OutputList &ol);
 void writeHeaderFileList(OutputList &ol);
+
 void writeExampleIndex(OutputList &ol);
 void writePageIndex(OutputList &ol);
-void writeFileMemberIndex(OutputList &ol);
+void writeFileIndex(OutputList &ol);
+void writeNamespaceIndex(OutputList &ol);
 void writeGroupIndex(OutputList &ol);
 void writeDirIndex(OutputList &ol);
-void writeNamespaceIndex(OutputList &ol);
+void writePackageIndex(OutputList &ol);
+
+void writeClassMemberIndex(OutputList &ol);
+void writeFileMemberIndex(OutputList &ol);
 void writeNamespaceMemberIndex(OutputList &ol);
+
 void writeGraphicalClassHierarchy(OutputList &ol);
 void writeGraphInfo(OutputList &ol);
-void writePackageIndex(OutputList &ol);
 
 void countDataStructures();
 
@@ -97,10 +101,10 @@ enum ClassMemberHighlight
   CMHL_Typedefs,
   CMHL_Enums,
   CMHL_EnumValues,
-  CMHL_Related,
   CMHL_Properties,
   CMHL_Events,
-  CMHL_Total = CMHL_Events+1
+  CMHL_Related,
+  CMHL_Total = CMHL_Related+1
 };
 
 enum FileMemberHighlight
