@@ -2,7 +2,7 @@
  *
  * 
  *
- * Copyright (C) 1997-2004 by Dimitri van Heesch.
+ * Copyright (C) 1997-2005 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -71,7 +71,7 @@ class MemberDef : public Definition
               bool related,MemberType t,const ArgumentList *tal,
               const ArgumentList *al);
    ~MemberDef(); 
-    DefType definitionType()              { return TypeMember; }
+    DefType definitionType() const        { return TypeMember; }
     
     // link id
     QCString getOutputFileBase() const;
@@ -106,6 +106,7 @@ class MemberDef : public Definition
     int getGroupStartLine() const            { return groupStartLine; }
     bool getGroupHasDocs() const             { return groupHasDocs; }
     QCString qualifiedName();
+    QCString objCMethodName(bool localLink,bool showStatic) const; 
 
     // direct kind info 
     Protection protection() const         { return prot; }
@@ -153,8 +154,9 @@ class MemberDef : public Definition
     bool isLinkable() const;
     bool hasDocumentation() const;  // overrides hasDocumentation in definition.h
     bool isBriefSectionVisible() const;
-    bool isDetailedSectionVisible(bool inGroup=FALSE) const;
+    bool isDetailedSectionVisible(bool inGroup,bool inFile) const;
     bool isDetailedSectionLinkable() const;
+    bool isFriendClass() const;
     bool isDocumentedFriendClass() const;
 
     // set functions
@@ -182,10 +184,10 @@ class MemberDef : public Definition
     void setHasDocumentedParams(bool b)     { m_hasDocumentedParams = b; }
     void setHasDocumentedReturnType(bool b) { m_hasDocumentedReturnType = b; }
     void setInheritsDocsFrom(MemberDef *md) { m_docProvider = md; }
+    void setTagInfo(TagInfo *i);
+    void setArgsString(const char *as)      { args = as; }
 
     // output generation
-    void writeLink(OutputList &ol,
-                   ClassDef *cd,NamespaceDef *nd,FileDef *fd,GroupDef *gd);
     void writeDeclaration(OutputList &ol,
                    ClassDef *cd,NamespaceDef *nd,FileDef *fd,GroupDef *gd,
                    bool inGroup); 
@@ -307,6 +309,10 @@ class MemberDef : public Definition
     bool visited;
     
   private:
+    void writeLink(OutputList &ol,
+                   ClassDef *cd,NamespaceDef *nd,FileDef *fd,GroupDef *gd,
+                   bool onlyText=FALSE);
+
     ClassDef   *classDef;     // member of or related to 
     FileDef    *fileDef;      // member of file definition 
     MemberDef  *enumScope;    // the enclosing scope, if this is an enum field
@@ -400,6 +406,11 @@ class MemberDef : public Definition
 
     // documentation inheritance
     MemberDef  *m_docProvider;
+
+    // to store the output file base from tag files
+    QCString explicitOutputFileBase;
+
+    bool m_isDMember;
 };
 
 #endif
