@@ -2,7 +2,7 @@
  *
  * $Id: memberlist.h,v 1.19 2001/03/19 19:27:41 root Exp $
  *
- * Copyright (C) 1997-2004 by Dimitri van Heesch.
+ * Copyright (C) 1997-2005 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -54,8 +54,11 @@ class MemberList : public QList<MemberDef>
                const char *title,const char *subtitle);
     void writeDocumentation(OutputList &ol,const char *scopeName,
                Definition *container,const char *title);
+    void writeDocumentationPage(OutputList &ol,
+               const char *scopeName, Definition *container);
     void addMemberGroup(MemberGroup *mg);
-    void setInGroup(bool group) { m_inGroup=group; }
+    void setInGroup(bool inGroup) { m_inGroup=inGroup; }
+    void setInFile(bool inFile) { m_inFile=inFile; }
     void addListReferences(Definition *def);
     void findSectionsInDocumentation();
     MemberGroupList *getMemberGroupList() const { return memberGroupList; }
@@ -66,7 +69,8 @@ class MemberList : public QList<MemberDef>
     int m_numDecMembers; // number of members in the brief part of the memberlist
     int m_numDocMembers; // number of members in the detailed part of the memberlist
     MemberGroupList *memberGroupList;
-    bool m_inGroup; // is this list part of a group
+    bool m_inGroup; // is this list part of a group definition
+    bool m_inFile;  // is this list part of a file definition
 };
 
 class MemberListIterator : public QListIterator<MemberDef>
