@@ -39,9 +39,10 @@ class GroupDef;
 
 /*! \brief Output interface for code parser. 
  */
-class BaseCodeDocInterface
+class CodeOutputInterface
 {
   public:
+    virtual ~CodeOutputInterface() {}
     /*! Writes an ASCII string to the output. This function should keep 
      *  spaces visible, should break lines at a newline and should convert 
      *  tabs to the right number of spaces.
@@ -78,9 +79,10 @@ class BaseCodeDocInterface
  *  or a list of formats (see OutputList). This interface
  *  contains functions that generate fragments of the output.
  */
-class BaseOutputDocInterface : public BaseCodeDocInterface
+class BaseOutputDocInterface : public CodeOutputInterface
 {
   public:
+    virtual ~BaseOutputDocInterface() {}
     enum ParamListTypes { Param, RetVal, Exception };
     enum SectionTypes { /*See, Return, Author, Version, 
                         Since, Date, Bug, Note,
@@ -272,7 +274,7 @@ class OutputGenerator : public BaseOutputDocInterface
     void pushGeneratorState();
     void popGeneratorState();
 
-    virtual void printDoc(DocNode *) = 0;
+    virtual void printDoc(DocNode *,const char *langExt) = 0;
 
     ///////////////////////////////////////////////////////////////
     // structural output interface
