@@ -21,6 +21,17 @@
 "\n"
 "function computeIndex($word)\n"
 "{\n"
+"  // Fast string hashing\n"
+"  //$lword = strtolower($word);\n"
+"  //$l = strlen($lword);\n"
+"  //for ($i=0;$i<$l;$i++)\n"
+"  //{\n"
+"  //  $c = ord($lword{$i});\n"
+"  //  $v = (($v & 0xfc00) ^ ($v << 6) ^ $c) & 0xffff;\n"
+"  //}\n"
+"  //return $v;\n"
+"\n"
+"  // Simple hashing that allows for substring search\n"
 "  if (strlen($word)<2) return -1;\n"
 "  // high char of the index\n"
 "  $hi = ord($word{0});\n"
@@ -39,7 +50,7 @@
 "  {\n"
 "    fseek($file,$index*4+4); // 4 bytes per entry, skip header\n"
 "    $index = readInt($file);\n"
-"    if ($index) // found words matching first two characters\n"
+"    if ($index) // found words matching the hash key\n"
 "    {\n"
 "      $start=sizeof($statsList);\n"
 "      $count=$start;\n"
@@ -281,6 +292,7 @@
 "  echo \"</span>\\n\";\n"
 "  echo \"</form>\\n\";\n"
 "  echo \"</div>\\n\";\n"
+"  echo \"<div class=\\\"searchresults\\\">\\n\";\n"
 "  $results = array();\n"
 "  $requiredWords = array();\n"
 "  $forbiddenWords = array();\n"
@@ -307,6 +319,7 @@
 "  sort_results($filteredDocs,$sorted);\n"
 "  // report results to the user\n"
 "  report_results($sorted);\n"
+"  echo \"</div>\\n\";\n"
 "  fclose($file);\n"
 "}\n"
 "\n"
