@@ -3,7 +3,7 @@
  * $Id: sortdict.h,v 1.3 2001/03/19 19:27:41 root Exp $
  *
  *
- * Copyright (C) 1997-2004 by Dimitri van Heesch.
+ * Copyright (C) 1997-2005 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -208,6 +208,14 @@ class SDict
     {
       return m_dict->find(key);
     }
+    T *find(const QCString &key)
+    {
+      return m_dict->find(key);
+    }
+    T *find(const QString &key)
+    {
+      return m_dict->find(key);
+    }
 
     /*! Equavalent to find(). */
     T *operator[](const char *key) const
