@@ -2,7 +2,7 @@
  *
  * 
  *
- * Copyright (C) 1997-2004 by Dimitri van Heesch.
+ * Copyright (C) 1997-2005 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -29,8 +29,8 @@ class Translator
     /* Tables for encoding conversions. */
     static const char Win1250ToISO88592Tab[];
     static const char ISO88592ToWin1250Tab[];
-    static Q_UINT16 Koi8RToWindows1251Tab[128];
-    static Q_UINT16 Windows1251ToKoi8RTab[128];
+    static const unsigned char Koi8RToWindows1251Tab[128];
+    static const unsigned char Windows1251ToKoi8RTab[128];
 
   protected:
     /*! Returns the string converted from windows-1250 to iso-8859-2. */
@@ -92,7 +92,7 @@ class Translator
     virtual QCString trClassHierarchy() = 0;
     virtual QCString trCompoundList() = 0;
     virtual QCString trFileList() = 0;
-    virtual QCString trHeaderFiles() = 0;
+    //virtual QCString trHeaderFiles() = 0;
     virtual QCString trCompoundMembers() = 0;
     virtual QCString trFileMembers() = 0;
     virtual QCString trRelatedPages() = 0;
@@ -103,11 +103,11 @@ class Translator
     virtual QCString trCompoundListDescription() = 0;
     virtual QCString trCompoundMembersDescription(bool extractAll) = 0;
     virtual QCString trFileMembersDescription(bool extractAll) = 0;
-    virtual QCString trHeaderFilesDescription() = 0;
+    //virtual QCString trHeaderFilesDescription() = 0;
     virtual QCString trExamplesDescription() = 0;
     virtual QCString trRelatedPagesDescription() = 0;
     virtual QCString trModulesDescription() = 0;
-    virtual QCString trNoDescriptionAvailable() = 0;
+    //virtual QCString trNoDescriptionAvailable() = 0;
     
     // index titles (the project name is prepended for these) 
 
@@ -133,7 +133,7 @@ class Translator
     virtual QCString trFunctionPrototypeDocumentation() = 0;
     virtual QCString trTypedefDocumentation() = 0;
     virtual QCString trEnumerationTypeDocumentation() = 0;
-    virtual QCString trEnumerationValueDocumentation() = 0;
+    //virtual QCString trEnumerationValueDocumentation() = 0;
     virtual QCString trFunctionDocumentation() = 0;
     virtual QCString trVariableDocumentation() = 0;
     virtual QCString trCompounds() = 0;
@@ -141,9 +141,9 @@ class Translator
     virtual QCString trWrittenBy() = 0;
     virtual QCString trClassDiagram(const char *clName) = 0;
     virtual QCString trForInternalUseOnly() = 0;
-    virtual QCString trReimplementedForInternalReasons() = 0;
+    //virtual QCString trReimplementedForInternalReasons() = 0;
     virtual QCString trWarning() = 0;
-    virtual QCString trBugsAndLimitations() = 0;
+    //virtual QCString trBugsAndLimitations() = 0;
     virtual QCString trVersion() = 0;
     virtual QCString trDate() = 0;
     virtual QCString trReturns() = 0;
@@ -223,7 +223,7 @@ class Translator
 // new since 0.49-991003
 //////////////////////////////////////////////////////////////////////////
 
-    virtual QCString trSources() = 0;
+    //virtual QCString trSources() = 0;
     virtual QCString trDefinedAtLineInSourceFile() = 0;
     virtual QCString trDefinedInSourceFile() = 0;
 
@@ -317,13 +317,13 @@ class Translator
 // new since 1.2.4
 //////////////////////////////////////////////////////////////////////////
 
-    virtual QCString trInterfaces() = 0;
+    //virtual QCString trInterfaces() = 0;
     virtual QCString trClasses() = 0;
     virtual QCString trPackage(const char *name) = 0;
     virtual QCString trPackageList() = 0;
     virtual QCString trPackageListDescription() = 0;
     virtual QCString trPackages() = 0;
-    virtual QCString trPackageDocumentation() = 0;
+    //virtual QCString trPackageDocumentation() = 0;
     virtual QCString trDefineValue() = 0;
     
 //////////////////////////////////////////////////////////////////////////
@@ -349,7 +349,7 @@ class Translator
     virtual QCString trGroup(bool first_capital, bool singular) = 0;
     virtual QCString trPage(bool first_capital, bool singular) = 0;
     virtual QCString trMember(bool first_capital, bool singular) = 0;
-    virtual QCString trField(bool first_capital, bool singular) = 0;
+    //virtual QCString trField(bool first_capital, bool singular) = 0;
     virtual QCString trGlobal(bool first_capital, bool singular) = 0;
 
 //////////////////////////////////////////////////////////////////////////
@@ -433,6 +433,12 @@ class Translator
     virtual QCString trDirReference(const char *dirName) = 0;
     virtual QCString trDir(bool first_capital, bool singular) = 0;
 
+//////////////////////////////////////////////////////////////////////////
+// new since 1.4.1
+//////////////////////////////////////////////////////////////////////////
+
+    virtual QCString trOverloadText() = 0;
+    
 };
 
 #endif
