@@ -1,5 +1,5 @@
 /******************************************************************************
- * Copyright (C) 1997-2004 by Dimitri van Heesch.
+ * Copyright (C) 1997-2005 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby
@@ -12,9 +12,11 @@
  *
  * Brazilian Portuguese version by
  *   Fabio "FJTC" Jun Takada Chino <jun-chino at uol.com.br>
- *   Version: 1.3.8 (2004/06/30)
+ *   Version: 1.4.1 (2005/03/20)
  *
  * History:
+ *   1.4.1
+ *		- Method trOverloadText() added.
  * 	 1.3.9
  *		- Updated to Doxygen 1.3.9
  * 	 1.3.8
@@ -1597,5 +1599,19 @@ class TranslatorBrazilian : public Translator
       if (!singular) result+="s";
       return result; 
     }
+//////////////////////////////////////////////////////////////////////////
+// new since 1.4.1
+//////////////////////////////////////////////////////////////////////////
+
+    /*! This text is added to the documentation when the \\overload command
+     *  is used for a overloaded function.
+     */
+    virtual QCString trOverloadText()
+    {
+       return "Este  um mtodo provido por convenincia. "
+       		"Ele difere do mtodo acima apenas na lista de "
+       		"argumentos que devem ser utilizados.";
+    }    
+    
 };
 #endif
