@@ -2,7 +2,7 @@
  *
  * 
  *
- * Copyright (C) 1997-2004 by Dimitri van Heesch.
+ * Copyright (C) 1997-2005 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -39,7 +39,7 @@
 // Translator class (by the local maintainer) when the localized
 // translator is made up-to-date again.
 
-class TranslatorCatalan : public TranslatorAdapter_1_2_17
+class TranslatorCatalan : public Translator
 {
   public:
 
@@ -91,30 +91,30 @@ class TranslatorCatalan : public TranslatorAdapter_1_2_17
 
     /*! header that is put before the detailed description of files, classes and namespaces. */
     virtual QCString trDetailedDescription()
-    { return "Descripci detallada"; }
+    { return "Descripci Detallada"; }
 
     /*! header that is put before the list of typedefs. */
     virtual QCString trMemberTypedefDocumentation()
-    { return "Documentaci de les Definicions de Tipus membre"; }
+    { return "Documentaci de les Definicions de Tipus Membre"; }
     
     /*! header that is put before the list of enumerations. */
     virtual QCString trMemberEnumerationDocumentation()
-    { return "Documentaci de les Enumeracions membre"; }
+    { return "Documentaci de les Enumeracions Membre"; }
     
     /*! header that is put before the list of member functions. */
     virtual QCString trMemberFunctionDocumentation()
-    { return "Documentaci de les Funcions membre"; }
+    { return "Documentaci de les Funcions Membre"; }
     
     /*! header that is put before the list of member attributes. */
     virtual QCString trMemberDataDocumentation()
     { 
       if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
       {
-        return "Documentaci dels camps"; 
+        return "Documentaci dels Camps"; 
       }
       else
       {
-        return "Documentaci de les dades membre"; 
+        return "Documentaci de les Dades Membre"; 
       }
     }
 
@@ -128,7 +128,7 @@ class TranslatorCatalan : public TranslatorAdapter_1_2_17
 
     /*! used as the title of the "list of all members" page of a class */
     virtual QCString trMemberList()
-    { return "Llista dels membres"; }
+    { return "Llista dels Membres"; }
 
     /*! this is the first part of a sentence that is followed by a class name */
     virtual QCString trThisIsTheListOfAllMembers()
@@ -181,28 +181,24 @@ class TranslatorCatalan : public TranslatorAdapter_1_2_17
       }
       else
       {
-        return "Llistes Compostes"; 
+        return "Llista de Classes"; 
       }
     }
     
     /*! This is put above each page as a link to the list of documented files */
     virtual QCString trFileList()
-    { return "Llista dels arxius"; }
-
-    /*! This is put above each page as a link to the list of all verbatim headers */
-    virtual QCString trHeaderFiles()
-    { return "Fitxers d'encapalaments"; }
+    { return "Llista dels Fitxers"; }
 
     /*! This is put above each page as a link to all members of compounds. */
     virtual QCString trCompoundMembers()
     { 
       if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
       {
-        return "Camps de dades"; 
+        return "Camps de Dades"; 
       }
       else
       {
-        return "Membres compostos"; 
+        return "Membres de Classes"; 
       }
     }
 
@@ -215,13 +211,13 @@ class TranslatorCatalan : public TranslatorAdapter_1_2_17
       }
       else
       {
-        return "Arxius membres";
+        return "Membres de Fitxers";
       }
     }
 
     /*! This is put above each page as a link to all related pages. */
     virtual QCString trRelatedPages()
-    { return "Pgines relacionades"; }
+    { return "Pgines Relacionades"; }
 
     /*! This is put above each page as a link to all examples. */
     virtual QCString trExamples()
@@ -240,7 +236,7 @@ class TranslatorCatalan : public TranslatorAdapter_1_2_17
     /*! This is an introduction to the list with all files. */
     virtual QCString trFileListDescription(bool extractAll)
     {
-      QCString result="Aquesta s la llista de tots els arxius ";
+      QCString result="Aquesta s la llista de tots els fitxers ";
       if (!extractAll) result+="documentats ";
       result+="acompanyats amb breus descripcions:";
       return result;
@@ -257,7 +253,7 @@ class TranslatorCatalan : public TranslatorAdapter_1_2_17
       else
       {
         return "Aquestes sn les classes, estructures, "
-               "unions i interfcies acompnyades amb breus descripcions:"; 
+               "unions i interfcies acompanyades amb breus descripcions:"; 
       }
     }
 
@@ -275,7 +271,7 @@ class TranslatorCatalan : public TranslatorAdapter_1_2_17
       }
       if (!extractAll)
       {
-        result+="documentats ";
+        result+=" documentats";
       }
       result+=" amb enllaos a ";
       if (!extractAll) 
@@ -293,11 +289,11 @@ class TranslatorCatalan : public TranslatorAdapter_1_2_17
       {
         if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
         {
-          result+="les estructures/unions que pertanyen a:";
+          result+="les estructures/unions a que pertanyen:";
         }
         else
         {
-          result+="les classes que pertanyen:";
+          result+="les classes a que pertanyen:";
         }
       }
       return result;
@@ -309,25 +305,21 @@ class TranslatorCatalan : public TranslatorAdapter_1_2_17
       if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
       {
         result+="totes les funcions, variables, definicions, enumeracions, i definicions de tipus";
-        if (!extractAll) result+="documentades ";
+        if (!extractAll) result+=" documentades";
       }
       else
       {
-        result+="tots els membres de l'arxiu";
-        if (!extractAll) result+="documentat ";
+        result+="tots els membres de fitxers";
+        if (!extractAll) result+=" documentats";
       }
       result+=" amb enllaos ";
       if (extractAll) 
-        result+="als arxius als quals corresponen:";
+        result+="als fitxers als quals corresponen:";
       else 
         result+="a la documentaci:";
       return result;
     }
 
-    /*! This is an introduction to the page with the list of all header files. */
-    virtual QCString trHeaderFilesDescription()
-    { return "Aquesta s la llista d'arxius d'encapalament que ofereix l'API:"; }
-
     /*! This is an introduction to the page with the list of all examples */
     virtual QCString trExamplesDescription()
     { return "Aquesta s la llista de tots els exemples:"; }
@@ -339,19 +331,13 @@ class TranslatorCatalan : public TranslatorAdapter_1_2_17
     /*! This is an introduction to the page with the list of class/file groups */
     virtual QCString trModulesDescription()
     { return "Aquesta s la llista de mduls:"; }
-
-    /*! This sentences is used in the annotated class/file lists if no brief
-     * description is given. 
-     */
-    virtual QCString trNoDescriptionAvailable()
-    { return "No hi ha cap descripci disponible"; }
     
     // index titles (the project name is prepended for these) 
 
 
     /*! This is used in HTML as the title of index.html. */
     virtual QCString trDocumentation()
-    { return "Documentaci"; }
+    { return ": Documentaci"; }
 
     /*! This is used in LaTeX as the title of the chapter with the 
      * index of all groups.
@@ -376,7 +362,7 @@ class TranslatorCatalan : public TranslatorAdapter_1_2_17
       }
       else
       {
-        return "ndex Compost"; 
+        return "ndex de Classes"; 
       }
     }
 
@@ -384,13 +370,13 @@ class TranslatorCatalan : public TranslatorAdapter_1_2_17
      * list of all files.
      */
     virtual QCString trFileIndex() 
-    { return "ndex d'Arxius"; }
+    { return "ndex de Fitxers"; }
 
     /*! This is used in LaTeX as the title of the chapter containing
      *  the documentation of all groups.
      */
     virtual QCString trModuleDocumentation()
-    { return "Documentaci dels mduls"; }
+    { return "Documentaci dels Mduls"; }
 
     /*! This is used in LaTeX as the title of the chapter containing
      *  the documentation of all classes, structs and unions.
@@ -411,7 +397,7 @@ class TranslatorCatalan : public TranslatorAdapter_1_2_17
      *  the documentation of all files.
      */
     virtual QCString trFileDocumentation()
-    { return "Documentaci dels Arxius"; }
+    { return "Documentaci dels Fitxers"; }
 
     /*! This is used in LaTeX as the title of the chapter containing
      *  the documentation of all examples.
@@ -423,7 +409,7 @@ class TranslatorCatalan : public TranslatorAdapter_1_2_17
      *  the documentation of all related pages.
      */
     virtual QCString trPageDocumentation()
-    { return "Documentaci de les pgines"; }
+    { return "Documentaci de les Pgines"; }
 
     /*! This is used in LaTeX as the title of the document */
     virtual QCString trReferenceManual()
@@ -495,12 +481,6 @@ class TranslatorCatalan : public TranslatorAdapter_1_2_17
     virtual QCString trEnumerationTypeDocumentation()
     { return "Documentaci dels Tipus de les Enumeracions"; }
 
-    /*! This is used in the documentation of a file/namespace before the list 
-     *  of documentation blocks for enumeration values
-     */
-    virtual QCString trEnumerationValueDocumentation()
-    { return "Documentaci dels Valors de les Enumeracions"; }
-
     /*! This is used in the documentation of a file/namespace before the list 
      *  of documentation blocks for functions
      */
@@ -524,7 +504,7 @@ class TranslatorCatalan : public TranslatorAdapter_1_2_17
       }
       else
       {
-        return "Compostos";
+        return "Classes";
       }
     }
 
@@ -555,18 +535,10 @@ class TranslatorCatalan : public TranslatorAdapter_1_2_17
     virtual QCString trForInternalUseOnly()
     { return "Tan sols per a s intern."; }
 
-    /*! this text is generated when the \\reimp command is used. */
-    virtual QCString trReimplementedForInternalReasons()
-    { return "Reimplementat per raons internes; l'API no es veu afectada."; }
-
     /*! this text is generated when the \\warning command is used. */
     virtual QCString trWarning()
     { return "Atenci"; }
 
-    /*! this text is generated when the \\bug command is used. */
-    virtual QCString trBugsAndLimitations()
-    { return "Errors i limitacions"; }
-
     /*! this text is generated when the \\version command is used. */
     virtual QCString trVersion()
     { return "Versi"; }
@@ -637,16 +609,16 @@ class TranslatorCatalan : public TranslatorAdapter_1_2_17
                                     ClassDef::CompoundType compType,
                                     bool isTemplate)
     {
-      QCString result="Referncia de la";
+      QCString result="Referncia de";
       switch(compType)
       {
-        case ClassDef::Class:      result+=" Classe "; break;
-        case ClassDef::Struct:     result+=" Estructura "; break;
-        case ClassDef::Union:      result+=" Uni "; break;
-        case ClassDef::Interface:  result+=" Interfcie "; break;
-        case ClassDef::Protocol:   result+=" Protocol "; break; // translate me!
-        case ClassDef::Category:   result+=" Category "; break; // translate me!
-        case ClassDef::Exception:  result+=" Excepci "; break;
+        case ClassDef::Class:      result+=" la Classe "; break;
+        case ClassDef::Struct:     result+=" l'Estructura "; break;
+        case ClassDef::Union:      result+=" la Uni "; break;
+        case ClassDef::Interface:  result+=" la Interfcie "; break;
+        case ClassDef::Protocol:   result+="l Protocol "; break;
+        case ClassDef::Category:   result+=" la Categoria "; break;
+        case ClassDef::Exception:  result+=" l'Excepci "; break;
       }
       if (isTemplate) result+="Template ";
       result+=(QCString)clName;
@@ -656,7 +628,7 @@ class TranslatorCatalan : public TranslatorAdapter_1_2_17
     /*! used as the title of the HTML page of a file */
     virtual QCString trFileReference(const char *fileName)
     {
-      QCString result="Referncia de l'Arxiu ";
+      QCString result="Referncia del Fitxer ";
       result+=fileName; 
       return result;
     }
@@ -720,7 +692,7 @@ class TranslatorCatalan : public TranslatorAdapter_1_2_17
      */
     virtual QCString trInheritsList(int numEntries)
     {
-      return "Hereda "+trWriteList(numEntries)+".";
+      return "Hereta de "+trWriteList(numEntries)+".";
     }
 
     /*! used in class documentation to produce a list of super classes,
@@ -728,7 +700,7 @@ class TranslatorCatalan : public TranslatorAdapter_1_2_17
      */
     virtual QCString trInheritedByList(int numEntries)
     {
-      return "Heredat per "+trWriteList(numEntries)+".";
+      return "Heretat per "+trWriteList(numEntries)+".";
     }
 
     /*! used in member documentation blocks to produce a list of 
@@ -796,22 +768,22 @@ class TranslatorCatalan : public TranslatorAdapter_1_2_17
         bool single)
     { // here s is one of " Class", " Struct" or " Union"
       // single is true implies a single file
-      QCString result=(QCString)"La documentaci d'aquesta ";
+      QCString result=(QCString)"La documentaci d'aquest";
       switch(compType)
       {
-        case ClassDef::Class:      result+="classe"; break;
-        case ClassDef::Struct:     result+="estructura"; break;
-        case ClassDef::Union:      result+="uni"; break;
-        case ClassDef::Interface:  result+="interfcie"; break;
-        case ClassDef::Protocol:   result+="protocol"; break; // translate me!
-        case ClassDef::Category:   result+="category"; break; // translate me!
-        case ClassDef::Exception:  result+="excepci"; break;
+        case ClassDef::Class:      result+="a classe"; break;
+        case ClassDef::Struct:     result+="a estructura"; break;
+        case ClassDef::Union:      result+="a uni"; break;
+        case ClassDef::Interface:  result+="a interfcie"; break;
+        case ClassDef::Protocol:   result+=" protocol"; break;
+        case ClassDef::Category:   result+="a categoria"; break;
+        case ClassDef::Exception:  result+="a excepci"; break;
       }
       result+=" es va generar a partir del";
       if (!single) result+="s";
       result+=" segent";
       if (!single) result+="s";
-      result+=" arxiu";
+      result+=" fitxer";
       if (!single) result+="s:"; else result+=":";
       return result;
     }
@@ -845,17 +817,13 @@ class TranslatorCatalan : public TranslatorAdapter_1_2_17
 // new since 0.49-991003
 //////////////////////////////////////////////////////////////////////////
 
-    virtual QCString trSources()
-    {
-      return "Codi Font";
-    }
     virtual QCString trDefinedAtLineInSourceFile()
     {
-      return "Definici a la lnia @0 de l'arxiu @1.";
+      return "Definici a la lnia @0 del fitxer @1.";
     }
     virtual QCString trDefinedInSourceFile()
     {
-      return "Definici a l'arxiu @0.";
+      return "Definici al fitxer @0.";
     }
 
 //////////////////////////////////////////////////////////////////////////
@@ -889,7 +857,7 @@ class TranslatorCatalan : public TranslatorAdapter_1_2_17
     /*! Used in the file documentation to point to the corresponding sources. */
     virtual QCString trGotoSourceCode()
     {
-      return "Veure el codi d'aquest arxiu.";
+      return "Veure el codi d'aquest fitxer.";
     }
     /*! Used in the file sources to point to the corresponding documentation. */
     virtual QCString trGotoDocumentation()
@@ -935,7 +903,7 @@ class TranslatorCatalan : public TranslatorAdapter_1_2_17
     }
     virtual QCString trPageIndex()
     {
-      return "Pgina ndex";
+      return "ndex de Pgines";
     }
 
 //////////////////////////////////////////////////////////////////////////
@@ -1023,8 +991,8 @@ class TranslatorCatalan : public TranslatorAdapter_1_2_17
     }
     virtual QCString trInclByDepGraph()
     {
-      return "Aquest grfic mostra quins arxius inclouen, "
-             "de forma directa o indirecta, aquest arxiu:";
+      return "Aquest grfic mostra quins fitxers inclouen, "
+             "de forma directa o indirecta, aquest fitxer:";
     }
     virtual QCString trSince()
     {
@@ -1148,11 +1116,6 @@ class TranslatorCatalan : public TranslatorAdapter_1_2_17
 // new since 1.2.4
 //////////////////////////////////////////////////////////////////////////
 
-    /*! Used for Java interfaces in the summary section of Java packages */
-    virtual QCString trInterfaces()
-    {
-      return "Interfcies";
-    }
     /*! Used for Java classes in the summary section of Java packages */
     virtual QCString trClasses()
     {
@@ -1185,11 +1148,6 @@ class TranslatorCatalan : public TranslatorAdapter_1_2_17
     {
       return "Paquets";
     }
-    /*! Used as a chapter title for Latex & RTF output */
-    virtual QCString trPackageDocumentation()
-    {
-      return "Documentaci dels Paquets";
-    }
     /*! Text shown before a multi-line define */
     virtual QCString trDefineValue()
     {
@@ -1277,7 +1235,7 @@ class TranslatorCatalan : public TranslatorAdapter_1_2_17
      */
     virtual QCString trFile(bool first_capital, bool singular)
     { 
-      QCString result((first_capital ? "Arxiu" : "arxiu"));
+      QCString result((first_capital ? "Fitxer" : "fitxer"));
       if (!singular)  result+="s";
       return result; 
     }
@@ -1326,17 +1284,6 @@ class TranslatorCatalan : public TranslatorAdapter_1_2_17
       return result; 
     }
    
-    /*! This is used for translation of the word that will possibly
-     *  be followed by a single name or by a list of names 
-     *  of the category.
-     */
-    virtual QCString trField(bool first_capital, bool singular)
-    { 
-      QCString result((first_capital ? "Camp" : "camp"));
-      if (!singular)  result+="s";
-      return result; 
-    }
-
     /*! This is used for translation of the word that will possibly
      *  be followed by a single name or by a list of names 
      *  of the category.
@@ -1403,6 +1350,213 @@ class TranslatorCatalan : public TranslatorAdapter_1_2_17
     {
       return "Taula de Continguts";
     }
+
+//////////////////////////////////////////////////////////////////////////
+// new since 1.2.17
+//////////////////////////////////////////////////////////////////////////
+
+    /*! Used as the header of the list of item that have been 
+     *  flagged deprecated 
+     */
+    virtual QCString trDeprecatedList()
+    {
+      return "Llista d'Antiquats";
+    }
+
+//////////////////////////////////////////////////////////////////////////
+// new since 1.2.18
+//////////////////////////////////////////////////////////////////////////
+
+    /*! Used as a header for declaration section of the events found in 
+     * a C# program
+     */
+    virtual QCString trEvents()
+    {
+      return "Esdeveniments";
+    }
+    /*! Header used for the documentation section of a class' events. */
+    virtual QCString trEventDocumentation()
+    {
+      return "Documentaci dels Esdeveniments";
+    }
+
+//////////////////////////////////////////////////////////////////////////
+// new since 1.3
+//////////////////////////////////////////////////////////////////////////
+
+    /*! Used as a heading for a list of Java class types with package scope.
+     */
+    virtual QCString trPackageTypes()
+    { 
+      return "Tipus de paquets";
+    }
+    /*! Used as a heading for a list of Java class functions with package 
+     * scope. 
+     */
+    virtual QCString trPackageMembers()
+    { 
+      return "Funcions de Paquet";
+    }
+    /*! Used as a heading for a list of static Java class functions with 
+     *  package scope.
+     */
+    virtual QCString trStaticPackageMembers()
+    { 
+      return "Funcions Esttiques de Paquet";
+    }
+    /*! Used as a heading for a list of Java class variables with package 
+     * scope.
+     */
+    virtual QCString trPackageAttribs()
+    { 
+      return "Atributs de Paquet";
+    }
+    /*! Used as a heading for a list of static Java class variables with 
+     * package scope.
+     */
+    virtual QCString trStaticPackageAttribs()
+    { 
+      return "Atributs Esttics de Paquet";
+    }
+    
+//////////////////////////////////////////////////////////////////////////
+// new since 1.3.1
+//////////////////////////////////////////////////////////////////////////
+
+    /*! Used in the quick index of a class/file/namespace member list page 
+     *  to link to the unfiltered list of all members.
+     */
+    virtual QCString trAll()
+    {
+      return "Tot";
+    }
+    /*! Put in front of the call graph for a function. */
+    virtual QCString trCallGraph()
+    {
+      return "Grfic de crides d'aquesta funci:";
+    }
+
+//////////////////////////////////////////////////////////////////////////
+// new since 1.3.3
+//////////////////////////////////////////////////////////////////////////
+
+    /*! When the search engine is enabled this text is put in the header 
+     *  of each page before the field where one can enter the text to search 
+     *  for. 
+     */
+    virtual QCString trSearchForIndex()
+    {
+      return "Buscar";
+    }
+    /*! This string is used as the title for the page listing the search
+     *  results.
+     */
+    virtual QCString trSearchResultsTitle()
+    {
+      return "Resultats de la Bsqueda";
+    }
+    /*! This string is put just before listing the search results. The
+     *  text can be different depending on the number of documents found.
+     *  Inside the text you can put the special marker $num to insert
+     *  the number representing the actual number of search results.
+     *  The @a numDocuments parameter can be either 0, 1 or 2, where the 
+     *  value 2 represents 2 or more matches. HTML markup is allowed inside
+     *  the returned string.
+     */
+    virtual QCString trSearchResults(int numDocuments)
+    {
+      if (numDocuments==0)
+      {
+        return "No s'ha trobat cap document.";
+      }
+      else if (numDocuments==1)
+      {
+        return "Trobat <b>1</b> document.";
+      }
+      else 
+      {
+        return "Trobats <b>$num</b> documents. "
+               "Mostrant els millors resultats primer.";
+      }
+    }
+    /*! This string is put before the list of matched words, for each search 
+     *  result. What follows is the list of words that matched the query.
+     */
+    virtual QCString trSearchMatches()
+    {
+      return "Resultats:";
+    }
+
+//////////////////////////////////////////////////////////////////////////
+// new since 1.3.8
+//////////////////////////////////////////////////////////////////////////
+
+    /*! This is used in HTML as the title of page with source code for file filename
+     */
+    virtual QCString trSourceFile(QCString& filename)
+    {
+      return "Fitxer de Codi " + filename;
+    }
+
+//////////////////////////////////////////////////////////////////////////
+// new since 1.3.9
+//////////////////////////////////////////////////////////////////////////
+
+    /*! This is used as the name of the chapter containing the directory
+     *  hierarchy.
+     */
+    virtual QCString trDirIndex()
+    { return "Jerarquia de Directoris"; }
+
+    /*! This is used as the name of the chapter containing the documentation
+     *  of the directories.
+     */
+    virtual QCString trDirDocumentation()
+    { return "Documentaci dels Directoris"; }
+
+    /*! This is used as the title of the directory index and also in the
+     *  Quick links of a HTML page, to link to the directory hierarchy.
+     */
+    virtual QCString trDirectories()
+    { return "Directoris"; }
+
+    /*! This returns a sentences that introduces the directory hierarchy. 
+     *  and the fact that it is sorted alphabetically per level
+     */
+    virtual QCString trDirDescription()
+    { return "Aquesta jerarquia de directoris est ordenada toscament, "
+             "per no completa, de forma alfabtica:";
+    }
+
+    /*! This returns the title of a directory page. The name of the
+     *  directory is passed via \a dirName.
+     */
+    virtual QCString trDirReference(const char *dirName)
+    { QCString result="Referncia del Directori "; result+=dirName; return result; }
+
+    /*! This returns the word directory with or without starting capital
+     *  (\a first_capital) and in sigular or plural form (\a singular).
+     */
+    virtual QCString trDir(bool first_capital, bool singular)
+    { 
+      QCString result((first_capital ? "Directori" : "directori"));
+      if (!singular) result+="s";
+      return result; 
+    }
+
+//////////////////////////////////////////////////////////////////////////
+// new since 1.4.1
+//////////////////////////////////////////////////////////////////////////
+
+    /*! This text is added to the documentation when the \\overload command
+     *  is used for a overloaded function.
+     */
+    virtual QCString trOverloadText()
+    {
+       return "Aquesta s una funci membre sobrecarregada, "
+              "proveda per convenincia. Es diferencia de la funci "
+              "anterior noms en els arguments que accepta.";
+    }
 };
 
 #endif
