@@ -2,7 +2,7 @@
  *
  * 
  *
- * Copyright (C) 1997-2004 by Dimitri van Heesch.
+ * Copyright (C) 1997-2005 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -27,101 +27,33 @@
 //
 // Updates:
 // --------
-// 2000/06/20
-//  - The prototype version of Czech strings with diacritics. The
-//    translation was based on translator.h of Doxygen version
-//    1.1.4 (from scratch).
-//
-// 2000/07/10
-//  - Updated version based on 1.1.5 sources (including important updates
-//    of the up-to-1.1.4 strings). Czech strings in this file were written
-//    in windows-1250 encoding. On-line decoding into iso-8859-2 ensured
-//    via conditional compilation if the sources are compiled under UNIX.
-//
-// 2000/07/19
-//  - Encoding conversion tables moved to the methods that use them.
-//  - Updates for "new since 1.1.5".
-//
-// 2000/08/02 (Petr Prikryl)
-//  - Updated for 1.2.0
-//
-// 2000/08/24
-//  - Changed trTodo() text from "Udelat" to "Planovane upravy"
-//    which seems more appropriate in the document context.
-//  - Typo corrected in trMemberTypedefDocumentation().
-//
-// 2000/08/30
-//  - Macro DECODE replaced by the inline Decode() (proposed by
-//    Boris Bralo <boris.bralo@zg.tel.hr> in translator_hr.h).
-//
-// 2000/08/31
-//  - Methods ISOToWin() and WinToISO() renamed and moved to the
-//    base class (in translator.h) to be shared with the Croatian
-//    translator.
-//
-// 2000/09/06
-//  - Reimplementation of the method trInheritsList() which takes 
-//    into account quantity of base classes.
-//
-// 2000/09/11
-//  - Update for "new since 1.2.1" version. The text of trDCOPMethods()
-//    was translated rather blindly (not knowing what exactly
-//    the DCOP means).
-//    
-// 2000/10/17
-//  - Update for "new since 1.2.2" version. 
-//
-// 2001/01/09
-//  - Update for "new since 1.2.4" version. As I do not use Java,
-//    I tried my best to guess the Czech terminology for the Java.
-//    Let me know if some wording should be changed/improved.
-//         
-// 2001/02/15
-//  - trMore() now returns only "..." (ellipsis).  The Czech replacement
-//    of "(more)" was too much visible.  The previous "(...)" did not 
-//    look well.
-//    
-// 2001/02/26
-//  - Update for "new since 1.2.5" version (trBug(), trBugList()).
-//         
-// 2001/03/12
-//  - Minor correction of comments which copied the same
-//    corrections in translator.h (doubled backslash) just after 
-//    1.2.6 release.
-//    
-// 2001/04/10
-//  - Update for OPTIMIZE_OUTPUT_FOR_C (1.2.6-20010408).
-//  - Removed implementation of latexBabelPackage().
-//  - Removed implementation of trVerbatimText().
-//  
-// 2001/04/20
-//  - Update for "new since 1.2.6-20010422". Experimental version
-//    introducing TranslatorAdapter class and the abstract base
-//    class Translator.  The English translator is now on the same
-//    level as other translators.
-//
-// 2001/05/02
-//  - The Decode() inline identifier changed to decode (i.e. lower
-//    case) to be consistent with HR and RU translator, which also
-//    use the approach.
-//  - Removed the obsolete method trFiles().
-//         
-// 2001/05/18 
-//  - The trRelatedPagesDescription() content updated to fit 
-//    the context better.
-//  - Implemented new method trAuthor(params).
-//  - Removed obsolete methods trAuthor() and trAuthors().
-//
-// 2001/05/25
-//  - Updated misleading information in trLegendDocs().
-//  - The trReimplementedInList() updated to fit the context better.
-//  - The trReimplementedFromList() updated to fit the context better.
-//
+// 2000/06/20 - Prototype: with diacritics; based on ver. 1.1.4 (from scratch).
+// 2000/07/10 - Update to 1.1.5; conditionally decoding to iso-8859-2 for UNIX.
+// 2000/07/19 - Updates for "new since 1.1.5"; encoding conversion separated.
+// 2000/08/02 - Updated for 1.2.0
+// 2000/08/24 - Corrections, updates.
+// 2000/08/30 - Macro DECODE replaced by the inline (thanks to Boris Bralo).
+// 2000/08/31 - ISOToWin() and WinToISO() moved to the base class.
+// 2000/09/06 - Reimplementation of trInheritsList().
+// 2000/09/11 - Update for "new since 1.2.1" version.
+// 2000/10/17 - Update for "new since 1.2.2" version. 
+// 2001/01/09 - Update for "new since 1.2.4" version.
+// 2001/02/15 - trMore() now returns only "..." (ellipsis).
+// 2001/02/26 - Update for "new since 1.2.5" version (trBug(), trBugList()).
+// 2001/03/12 - Minor correction of comments (synchronous with translator.h).
+// 2001/04/10 - Updates (1.2.6-20010408), cleaning.
+// 2001/04/20 - Update for "new since 1.2.6-20010422". Experimental version
+//              introducing TranslatorAdapter class and the abstract base
+//              class Translator.  The English translator is now on the same
+//              level as other translators.
+// 2001/05/02 - Decode() inline changed to decode(); cleaning.
+// 2001/05/18 - Updates, corrections.
+// 2001/05/25 - Corrections.
 // 2001/07/16 - trClassDocumentation() updated as in the English translator.
 // 2001/11/06 - trReferences() implemented.
 // 2002/01/23 - Two new methods "since 1.2.13" implemented.
 // 2002/03/05 - ... forgot to replace TranslatorAdapter... by Translator.
-// 2002/07/08 (my birthday! ;) - The new trRTFTableOfContents() implemented.
+// 2002/07/08 - The new trRTFTableOfContents() implemented. (my birthday! ;) 
 // 2002/07/29 - The new trDeprecatedList() implemented.
 // 2002/10/15 - The new trEvents() and trEventDocumentation() implemented.
 // 2003/04/28 - Five new methods "since 1.3" implemented.
@@ -131,6 +63,8 @@
 // 2004/02/27 - Text inside the trCallGraph() corrected.
 // 2004/06/16 - The new method "since 1.3.8" implemented. 
 // 2004/09/14 - The new methods "since 1.3.9" implemented. 
+// 2005/02/11 - The "never used" methods removed.
+// 2005/03/08 - Update for "new since 1.4.1" (trOverloadText()) 
 
 // Todo
 // ----
@@ -301,10 +235,6 @@ class TranslatorCzech : public Translator
     virtual QCString trFileList()
     { return decode("Seznam soubor"); }
 
-    /*! This is put above each page as a link to the list of all verbatim headers */
-    virtual QCString trHeaderFiles()
-    { return decode("Seznam hlavikovch soubor"); }
-
     /*! This is put above each page as a link to all members of compounds. */
     virtual QCString trCompoundMembers()
     { 
@@ -447,11 +377,6 @@ class TranslatorCzech : public Translator
       return decode(result);
     }
 
-    /*! This is an introduction to the page with the list of all header files. */
-    virtual QCString trHeaderFilesDescription()
-    { return decode("Zde naleznete hlavikov soubory, kter tvo "
-             "aplikan programtorsk rozhran (API):"); }
-
     /*! This is an introduction to the page with the list of all examples */
     virtual QCString trExamplesDescription()
     { return decode("Zde naleznete seznam vech pklad:"); }
@@ -464,12 +389,6 @@ class TranslatorCzech : public Translator
     virtual QCString trModulesDescription()
     { return decode("Zde naleznete seznam vech modul:"); }
 
-    /*! This sentences is used in the annotated class/file lists if no brief
-     * description is given. 
-     */
-    virtual QCString trNoDescriptionAvailable()
-    { return decode("Popis nen k dispozici"); }
-    
     // index titles (the project name is prepended for these) 
 
 
@@ -619,12 +538,6 @@ class TranslatorCzech : public Translator
     virtual QCString trEnumerationTypeDocumentation()
     { return decode("Dokumentace vtovch typ"); }
 
-    /*! This is used in the documentation of a file/namespace before the list 
-     *  of documentation blocks for enumeration values
-     */
-    virtual QCString trEnumerationValueDocumentation()
-    { return decode("Dokumentace vtovch hodnot"); }
-
     /*! This is used in the documentation of a file/namespace before the list 
      *  of documentation blocks for functions
      */
@@ -679,19 +592,10 @@ class TranslatorCzech : public Translator
     virtual QCString trForInternalUseOnly()
     { return decode("Pouze pro vnitn pouit."); }
 
-    /*! this text is generated when the \\reimp command is used. */
-    virtual QCString trReimplementedForInternalReasons()
-    { return decode("Reimplementovno z internch dvod; "
-                    "aplikan rozhran zachovno."); }
-
     /*! this text is generated when the \\warning command is used. */
     virtual QCString trWarning()
     { return decode("Pozor"); }
 
-    /*! this text is generated when the \\bug command is used. */
-    virtual QCString trBugsAndLimitations()
-    { return decode("Chyby a omezen"); }
-
     /*! this text is generated when the \\version command is used. */
     virtual QCString trVersion()
     { return decode("Verze"); }
@@ -979,10 +883,6 @@ class TranslatorCzech : public Translator
 // new since 0.49-991003
 //////////////////////////////////////////////////////////////////////////
 
-    virtual QCString trSources()
-    {
-      return decode("Zdroje");
-    }
     virtual QCString trDefinedAtLineInSourceFile()
     {
       return decode("Definice je uvedena na dku @0 v souboru @1.");
@@ -1304,11 +1204,6 @@ class TranslatorCzech : public Translator
 // new since 1.2.4
 //////////////////////////////////////////////////////////////////////////
 
-    /*! Used for Java interfaces in the summary section of Java packages */
-    virtual QCString trInterfaces()
-    {
-      return decode("Rozhran");
-    }
     /*! Used for Java classes in the summary section of Java packages */
     virtual QCString trClasses()
     {
@@ -1335,11 +1230,6 @@ class TranslatorCzech : public Translator
     {
       return decode("Balky");
     }
-    /*! Used as a chapter title for Latex & RTF output */
-    virtual QCString trPackageDocumentation()
-    {
-      return decode("Dokumentace balku");
-    }
     /*! Text shown before a multi-line define */
     virtual QCString trDefineValue()
     {
@@ -1450,17 +1340,6 @@ class TranslatorCzech : public Translator
       return decode(result); 
     }
    
-    /*! This is used for translation of the word that will possibly
-     *  be followed by a single name or by a list of names 
-     *  of the category.
-     */
-    virtual QCString trField(bool first_capital, bool singular)
-    { 
-      QCString result((first_capital ? "Polok" : "polok"));
-      result+=(singular ? "a" : "y");
-      return decode(result); 
-    }
-
     /*! ??? Jak to prelozit? Bylo by dobre, kdyby se ozval nekdo,
      * kdo to pouziva.
      */
@@ -1727,6 +1606,20 @@ class TranslatorCzech : public Translator
             result += "e";
         return decode(result); 
     }
+
+//////////////////////////////////////////////////////////////////////////
+// new since 1.4.1
+//////////////////////////////////////////////////////////////////////////
+
+    /*! This text is added to the documentation when the \\overload command
+     *  is used for a overloaded function.
+     */
+    virtual QCString trOverloadText()
+    {
+       return decode("Jde o petenou (overloaded) metodu, "
+              "kter m usnadnit pouvn. Od ve uveden metody se li "
+              "pouze jinak zadvanmi argumenty.");
+    }
 };
 
 #endif // TRANSLATOR_CZ_H
