@@ -2,7 +2,7 @@
  *
  * 
  *
- * Copyright (C) 1997-2004 by Dimitri van Heesch.
+ * Copyright (C) 1997-2005 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -60,6 +60,8 @@
  *              | - translator_fr.h now conforms exactly to translator_en.h
  *              |   (try: gvim -d translator_en.h translator_fr.h)
  * -------------+------------------------------------------------------------
+ *  2005-07-12  | Update for new since 1.4.1
+ * -------------+------------------------------------------------------------
  */ 
 #ifndef TRANSLATOR_FR_H
 #define TRANSLATOR_FR_H
@@ -519,7 +521,7 @@ class TranslatorFrench : public Translator
      *  documentation blocks for defines
      */
     virtual QCString trDefineDocumentation()
-    { return "Documentation des macro"; }
+    { return "Documentation des macros"; }
 
     /*! This is used in the documentation of a file/namespace before the list 
      *  of documentation blocks for function prototypes
@@ -1650,6 +1652,20 @@ class TranslatorFrench : public Translator
        return result;
      }
 
+//////////////////////////////////////////////////////////////////////////
+// new since 1.4.1
+//////////////////////////////////////////////////////////////////////////
+
+    /*! This text is added to the documentation when the \\overload command
+     *  is used for a overloaded function.
+     */
+    virtual QCString trOverloadText()
+    {
+       return "Ceci est une fonction membre surcharge, "
+              "propose par commodit. Elle diffre de la fonction "
+              "i-dessus uniquement par le(s) argument(s) qu'elle accepte.";
+    }
 };
 
 #endif
+
