@@ -2,7 +2,7 @@
  *
  *
  *
- * Copyright (C) 1997-2004 by Dimitri van Heesch.
+ * Copyright (C) 1997-2005 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby
@@ -19,6 +19,8 @@
  *
  * Revision history
  *
+ *  2005/03: translated new items used since version 1.4.1
+ *           removed unused methods listed in Petr Prikryl February 28 translator report
  *  2004/09: translated new items used since version 1.3.9
  *  2004/06: translated new items used since version 1.3.8
  *  2003/11: translated new items used since version 1.3.3
@@ -28,7 +30,7 @@
  *  2002/08: translated new items used since version 1.2.17
  *  2002/07: translated new items used since version 1.2.16
  *  2002/06: modified trRelatedPagesDescription() method
- *           correct typo in trInclByDepGraph() method
+ *           corrected typo in trInclByDepGraph() method
  *  2002/01: translated new items used since version 1.2.13
  *           updated e-mail address
  *  2001/11: corrected the translation fixing the issues reported by the translator.pl script
@@ -212,10 +214,6 @@ class TranslatorItalian : public Translator
     QCString trFileList()
     { return "Lista dei file"; }
 
-    /*! This is put above each page as a link to the list of all verbatim headers */
-    QCString trHeaderFiles()
-    { return "Lista dei file header"; }
-
     /*! This is put above each page as a link to all members of compounds. */
     QCString trCompoundMembers()
      {
@@ -333,10 +331,6 @@ class TranslatorItalian : public Translator
       return result;
     }
 
-    /*! This is an introduction to the page with the list of all header files. */
-    QCString trHeaderFilesDescription()
-    { return "Questi sono gli header file che compongono l'API:"; }
-
     /*! This is an introduction to the page with the list of all examples */
     QCString trExamplesDescription()
     { return "Questa  la lista di tutti gli esempi:"; }
@@ -349,15 +343,8 @@ class TranslatorItalian : public Translator
     QCString trModulesDescription()
     { return "Questa  la lista di tutti i moduli:"; }
 
-    /*! This sentences is used in the annotated class/file lists if no brief
-     * description is given.
-     */
-    QCString trNoDescriptionAvailable()
-    { return "Descrizione non disponibile"; }
-
     // index titles (the project name is prepended for these)
 
-
     /*! This is used in HTML as the title of index.html. */
     QCString trDocumentation()
     { return "Documentazione"; }
@@ -495,12 +482,6 @@ class TranslatorItalian : public Translator
     QCString trEnumerationTypeDocumentation()
     { return "Documentazione dei tipi enumerati"; }
 
-    /*! This is used in the documentation of a file/namespace before the list
-     *  of documentation blocks for enumeration values
-     */
-    QCString trEnumerationValueDocumentation()
-    { return "Documentazione dei valori dei tipi enumerati"; }
-
     /*! This is used in the documentation of a file/namespace before the list
      *  of documentation blocks for functions
      */
@@ -555,18 +536,10 @@ class TranslatorItalian : public Translator
     QCString trForInternalUseOnly()
     { return "Solo per uso interno."; }
 
-    /*! this text is generated when the \\reimp command is used. */
-    QCString trReimplementedForInternalReasons()
-    { return "Reimplementato per motivi interni; l'API non  stata modificata.";}
-
     /*! this text is generated when the \\warning command is used. */
     QCString trWarning()
     { return "Avvertimento"; }
 
-    /*! this text is generated when the \\bug command is used. */
-    QCString trBugsAndLimitations()
-    { return "Bug e limitazioni"; }
-
     /*! this text is generated when the \\version command is used. */
     QCString trVersion()
     { return "Versione"; }
@@ -846,10 +819,6 @@ class TranslatorItalian : public Translator
 // new since 0.49-991003
 //////////////////////////////////////////////////////////////////////////
 
-    QCString trSources()
-    {
-      return "Sorgenti";
-    }
     QCString trDefinedAtLineInSourceFile()
     {
       return "Definizione alla linea @0 del file @1.";
@@ -1142,11 +1111,6 @@ class TranslatorItalian : public Translator
 // new since 1.2.4
 //////////////////////////////////////////////////////////////////////////
 
-    /*! Used for Java interfaces in the summary section of Java packages */
-    virtual QCString trInterfaces()
-    {
-      return "Interfacce";
-    }
     /*! Used for Java classes in the summary section of Java packages */
     virtual QCString trClasses()
     {
@@ -1179,11 +1143,6 @@ class TranslatorItalian : public Translator
     {
       return "Package";
     }
-    /*! Used as a chapter title for Latex & RTF output */
-    virtual QCString trPackageDocumentation()
-    {
-      return "Documentazione dei package";
-    }
     /*! Text shown before a multi-line define */
     virtual QCString trDefineValue()
     {
@@ -1291,17 +1250,6 @@ class TranslatorItalian : public Translator
       return result;
     }
 
-    /*! This is used for translation of the word that will possibly
-     *  be followed by a single name or by a list of names
-     *  of the category.
-     */
-    virtual QCString trField(bool first_capital, bool singular)
-    {
-      QCString result((first_capital ? "Camp" : "camp"));
-      result+=(singular ? "o" : "i");
-      return result;
-    }
-
     /*! This is used for translation of the word that will possibly
      *  be followed by a single name or by a list of names
      *  of the category.
@@ -1562,6 +1510,20 @@ class TranslatorItalian : public Translator
       return result;
     }
 
+//////////////////////////////////////////////////////////////////////////
+// new since 1.4.1
+//////////////////////////////////////////////////////////////////////////
+
+    /*! This text is added to the documentation when the \\overload command
+     *  is used for a overloaded function.
+     */
+    virtual QCString trOverloadText()
+    {
+       return "Questa  una funzione membro sovraccaricata (overloaded), "
+              "fornita per comodit. Differisce dalla funzione di cui sopra"
+              "unicamente per gli argomenti passati.";
+    }
+
 };
 
 #endif
