@@ -2,7 +2,7 @@
  *
  * 
  *
- * Copyright (C) 1997-2004 by Dimitri van Heesch.
+ * Copyright (C) 1997-2005 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -51,30 +51,38 @@
 //
 //	Update:
 //
-// 2004.12.22 (SooYoung Jung: jung5000@gmail.com)
-//	- LaTex and RTF were not generated correctly.
-// 	  Corrected trRTFansicp and trRTFCharSet.
-// 	  It was wrong.
-// 	- Adapting 1.3.9 and added "new since 1.3.9"
-//	- ؼ ߸ κ ҳ ־ .. 
+// 2004.12.22 (SooYoung Jung: jung5000 at gmail.com)
+//  - LaTex and RTF were not generated correctly.
+//    Corrected trRTFansicp and trRTFCharSet.
+//    It was wrong.
+//  - Adapting 1.3.9 and added "new since 1.3.9"
+//  - ؼ ߸ κ ҳ ־ .. 
+//
+// 2005.02.11 (SooYoung Jung: jung5000 at gmail.com)
+//  - Ǽ ߰Ǿ decode Լ 
+//
+// 2005.03.11 (SooYoung Jung: jung5000 at gmail.com)
+//  - Adapting 1.4.1 and checked using translator.py
+//  - Ϻ ȵ κ  (Translated little bit of untranslated part)
+//  - Removed following
+//    Obsolete methods (should be removed, never used):
+//    virtual QCString trHeaderFilesDescription()
+//    virtual QCString trField(bool first_capital, bool singular)
+//    virtual QCString trPackageDocumentation()
+//    virtual QCString trSources()
+//    virtual QCString trReimplementedForInternalReasons()
+//    virtual QCString trInterfaces()
+//    virtual QCString trHeaderFiles()
+//    virtual QCString trBugsAndLimitations()
+//    virtual QCString trEnumerationValueDocumentation()
+//    virtual QCString trNoDescriptionAvailable()
+//  - Changed the base class to Translator from Translator_1_4_1
 //
  
 
-class TranslatorKorean : public TranslatorAdapter_1_3_9
+class TranslatorKorean : public Translator
 {
  private:
-  /*! The decode() can change euc into sjis */
-  inline QCString decode(const QCString & sInput)
-  {
-    if (Config_getBool("USE_WINDOWS_ENCODING"))
-    {
-      return JapaneseEucToSjis(sInput);
-    }
-    else
-    {
-      return sInput;
-    }
-  }
   	
   public:
 
@@ -182,7 +190,7 @@ class TranslatorKorean : public TranslatorAdapter_1_3_9
     virtual QCString trGeneratedAutomatically(const char *s)
     { QCString result="";
       if (s) result+=(QCString)s+" ";
-      result += "source ڵ  Doxygen  ڵ ";
+      result += "ҽ ڵ  Doxygen  ڵ ";
       return result;
     }
 
@@ -213,50 +221,25 @@ class TranslatorKorean : public TranslatorAdapter_1_3_9
     /*! This is put above each page as a link to the list of annotated classes */
     virtual QCString trCompoundList()
     {
-        if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
-        {
-            //Alternate text: "ȥ ", "ռ() (Ʈ)"
-            return "ձ(Ŭ, ü, ü)";
-        }
-        else
-        {
-            return "ձ(Ŭ, ü, ü)";
-        }
+        //Alternate text: "ȥ ", "ռ() (Ʈ)"
+        return "ձ(Ŭ, ü, ü)";
     }
     
     /*! This is put above each page as a link to the list of documented files */
     virtual QCString trFileList()
     { return " "; } //" ", " Ʈ"
 
-    /*! This is put above each page as a link to the list of all verbatim headers */
-    virtual QCString trHeaderFiles()
-    { return " "; }
-
     /*! This is put above each page as a link to all members of compounds. */
     virtual QCString trCompoundMembers()
     {
-        if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
-        {
-            return "ձ(Ŭ, ü, ü) ";
-        }
-        else
-        {
-            // Alternate text: "ռ() ()"
-            return "ձ(Ŭ, ü, ü) ";
-        }
+      // Alternate text: "ռ() ()"
+      return "ձ(Ŭ, ü, ü) ";
     }
 
     /*! This is put above each page as a link to all members of files. */
     virtual QCString trFileMembers()
     {
-        if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
-        {
-            return " ";
-        }
-        else
-        {
-            return " ";
-        }
+      return " ";
     }
 
     /*! This is put above each page as a link to all related pages. */
@@ -287,16 +270,8 @@ class TranslatorKorean : public TranslatorAdapter_1_3_9
     /*! This is an introduction to the annotated compound list. */
     virtual QCString trCompoundListDescription()
     {
-        if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
-        {
-            return "    Ŭ, "
-                "ü, ü, ̽ Դϴ.";
-        }
-        else
-        {
-            return "    Ŭ, "
-                "ü, ü, ̽ Դϴ.";
-        }
+      return "    Ŭ, "
+	"ü, ü, ̽ Դϴ.";
     }
 
     /*! This is an introduction to the page with all class members. */
@@ -307,14 +282,8 @@ class TranslatorKorean : public TranslatorAdapter_1_3_9
       {
           result+="ȭ ";
       }
-      if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
-      {
-          result+="ũ  Ŭ  ";
-      }
-      else
-      {
-          result+="ũ  Ŭ  ";
-      }
+      
+      result+="ũ  Ŭ  ";
 
       if (extractAll)
           result+="   Ŭ ȭ ϴ.";
@@ -336,10 +305,6 @@ class TranslatorKorean : public TranslatorAdapter_1_3_9
       return result;
     }
 
-    /*! This is an introduction to the page with the list of all header files. */
-    virtual QCString trHeaderFilesDescription()
-    { return " API ϴ  Դϴ."; }
-
     /*! This is an introduction to the page with the list of all examples */
     virtual QCString trExamplesDescription()
     { return "   Դϴ."; }
@@ -352,15 +317,8 @@ class TranslatorKorean : public TranslatorAdapter_1_3_9
     virtual QCString trModulesDescription()
     { return "   Դϴ."; }
 
-    /*! This sentences is used in the annotated class/file lists if no brief
-     * description is given.
-     */
-    virtual QCString trNoDescriptionAvailable()
-    { return "  ϴ."; }
-
     // index titles (the project name is prepended for these)
 
-
     /*! This is used in HTML as the title of index.html. */
     virtual QCString trDocumentation()
     { return "ȭ"; }
@@ -489,12 +447,6 @@ class TranslatorKorean : public TranslatorAdapter_1_3_9
     virtual QCString trEnumerationTypeDocumentation()
     { return " Ÿ ȭ"; }
 
-    /*! This is used in the documentation of a file/namespace before the list 
-     *  of documentation blocks for enumeration values
-     */
-    virtual QCString trEnumerationValueDocumentation()
-    { return "  ȭ"; }
-
     /*! This is used in the documentation of a file/namespace before the list 
      *  of documentation blocks for functions
      */
@@ -514,11 +466,11 @@ class TranslatorKorean : public TranslatorAdapter_1_3_9
     { 
       if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
       {
-        return "Data Structures"; 
+        return " "; 
       }
       else
       {
-        return "Classes"; 
+        return "Ŭ"; 
       }
     }
 
@@ -529,14 +481,14 @@ class TranslatorKorean : public TranslatorAdapter_1_3_9
     {
       QCString result="";
       if (projName) result+=(QCString)projName+" ȭ. ";
-      result += "Ͻ : " +(QCString)date+" by";
+      result += "Ͻ : " +(QCString)date;
       return result;
     }
     /*! This is part of the sentence used in the standard footer of each page.
      */
     virtual QCString trWrittenBy()
     {
-      return "written by";
+      return "ۼ: ";
     }
 
     /*! this text is put before a class diagram */
@@ -549,18 +501,10 @@ class TranslatorKorean : public TranslatorAdapter_1_3_9
     virtual QCString trForInternalUseOnly()
     { return " 븸 "; }
 
-    /*! this text is generated when the \\reimp command is used. */
-    virtual QCString trReimplementedForInternalReasons()
-    { return "   籸: API  ʾҴ."; }
-
     /*! this text is generated when the \\warning command is used. */
     virtual QCString trWarning()
     { return ""; }
 
-    /*! this text is generated when the \\bug command is used. */
-    virtual QCString trBugsAndLimitations()
-    { return "׿ Ѱ"; }
-
     /*! this text is generated when the \\version command is used. */
     virtual QCString trVersion()
     { return ""; }
@@ -639,8 +583,8 @@ class TranslatorKorean : public TranslatorAdapter_1_3_9
         case ClassDef::Struct:     result+=" ü"; break;
         case ClassDef::Union:      result+=" ü"; break;
         case ClassDef::Interface:  result+=" ̽"; break;
-        case ClassDef::Protocol:   result+=" protocol"; break; // translate me!
-        case ClassDef::Category:   result+=" category"; break; // translate me!
+        case ClassDef::Protocol:   result+=" "; break;
+        case ClassDef::Category:   result+=" īװ"; break;
         case ClassDef::Exception:  result+=" "; break;
       }
       if (isTemplate) result+=" ø";
@@ -799,8 +743,8 @@ class TranslatorKorean : public TranslatorAdapter_1_3_9
         case ClassDef::Struct:     result+="ü"; break;
         case ClassDef::Union:      result+="ü"; break;
         case ClassDef::Interface:  result+="̽"; break;
-        case ClassDef::Protocol:   result+="protocol"; break; // translate me!
-        case ClassDef::Category:   result+="category"; break; // translate me!
+        case ClassDef::Protocol:   result+=""; break;
+        case ClassDef::Category:   result+="īװ"; break;
         case ClassDef::Exception:  result+=""; break;
       }
       result+="  ȭ  ";
@@ -838,10 +782,6 @@ class TranslatorKorean : public TranslatorAdapter_1_3_9
 // new since 0.49-991003
 //////////////////////////////////////////////////////////////////////////
 
-    virtual QCString trSources()
-    {
-      return "ó";
-    }
     virtual QCString trDefinedAtLineInSourceFile()
     {
       return "@1  @0 ° ο ";
@@ -947,7 +887,7 @@ class TranslatorKorean : public TranslatorAdapter_1_3_9
     {
       if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
       {
-          return "Data ʵ";
+          return "Ÿ ʵ";
       }
       else
       {
@@ -1016,13 +956,12 @@ class TranslatorKorean : public TranslatorAdapter_1_3_9
     }
     virtual QCString trInclByDepGraph()
     {
-        // TODO: Need to be translated. -ryk11/22/01.
-        return "This graph shows which files directly or "
-             "indirectly include this file:";
+	return "  ׷    Ǵ "
+	  "(include) Ÿ:";
     }
     virtual QCString trSince()
     {
-        return "Since"; // TODO: Need to be translated. -ryk11/22/01.
+        return ": "; // TODO: Need to be translated. -ryk11/22/01.
     }
     
 //////////////////////////////////////////////////////////////////////////
@@ -1041,85 +980,85 @@ class TranslatorKorean : public TranslatorAdapter_1_3_9
     {
         // TODO: Need to be translated. -ryk11/22/01.
         return
-		"Doxygen   ǥ  Դϴ.<p>\n"
-        //"This page explains how to interpret the graphs that are generated "
-        //"by doxygen.<p>\n"
-		"  ϼ.\n"
-        //"Consider the following example:\n"
-        "\\code\n"
-        "/*! Invisible class because of truncation */\n"
-        "class Invisible { };\n\n"
-        "/*! Truncated class, inheritance relation is hidden */\n"
-        "class Truncated : public Invisible { };\n\n"
-        "/* Class not documented with doxygen comments */\n"
-        "class Undocumented { };\n\n"
-        "/*! Class that is inherited using public inheritance */\n"
-        "class PublicBase : public Truncated { };\n\n"
-        "/*! A template class */\n"
-        "template<class T> class Templ { };\n\n"
-        "/*! Class that is inherited using protected inheritance */\n"
-        "class ProtectedBase { };\n\n"
-        "/*! Class that is inherited using private inheritance */\n"
-        "class PrivateBase { };\n\n"
-        "/*! Class that is used by the Inherited class */\n"
-        "class Used { };\n\n"
-        "/*! Super class that inherits a number of other classes */\n"
-        "class Inherited : public PublicBase,\n"
-        "                  protected ProtectedBase,\n"
-        "                  private PrivateBase,\n"
-        "                  public Undocumented\n"
-        "                  public Templ<int>\n"
-        "{\n"
-        "  private:\n"
-        "    Used *m_usedClass;\n"
-        "};\n"
-        "\\endcode\n"
-		"  MAX_DOT_GRAPH_HEIGHT ÷װ 240 Ǿٸ  ׷  ̴."
-        //"If the \\c MAX_DOT_GRAPH_HEIGHT tag in the configuration file "
-        //"is set to 240 this will result in the following graph:"
-        "<p><center><img src=\"graph_legend."+Config_getEnum("DOT_IMAGE_FORMAT")+"\"></center>\n"
-        "<p>\n"
-		"ڵ  Ѵ.\n"
-        //"The boxes in the above graph have the following meaning:\n"
-        "<ul>\n"
-		"<li>% ڴ ׷  ü Ŭ Ѵ.\n"
-        //"<li>%A filled black box represents the struct or class for which the "
-        //"graph is generated.\n"
-		"<li>%ε ڴ ȭ ü Ŭ ǥѴ.\n"
-        //"<li>%A box with a black border denotes a documented struct or class.\n"
-		"<li>%ȸε ڴ ȭ  ü Ŭ ǥѴ.\n"
-        //"<li>%A box with a grey border denotes an undocumented struct or class.\n"
-		"<li>%ε ڴ  /containment 踦   ȭ ü Ŭ Ÿ. "
-		" ȿ   ׷ ©.\n"
-        //"<li>%A box with a red border denotes a documented struct or class for"
-        //"which not all inheritance/containment relations are shown. %A graph is "
-        //"truncated if it does not fit within the specified boundaries.\n"
-        "</ul>\n"
-		"ȭǥ  Ѵ.\n"
-        //"The arrows have the following meaning:\n"
-        "<ul>\n"
-		"<li>%ο Ķ ȭǥ  Ŭ public Ӱ踦 Ÿ.\n"
-        //"<li>%A dark blue arrow is used to visualize a public inheritance "
-        //"relation between two classes.\n"
-		"<li>%ο  ȭǥ protected Ӱ踦 Ÿ.\n"
-        //"<li>%A dark green arrow is used for protected inheritance.\n"
-		"<li>%ο  ȭǥ private Ӱ踦 Ÿ.\n"
-        //"<li>%A dark red arrow is used for private inheritance.\n"
-		"<li>% ֻ ȭǥ Ŭ  ԵǴ  Ŭ Ÿ. "
-		" ȭǥ     Ÿ.\n"
-        //"<li>%A purple dashed arrow is used if a class is contained or used "
-        //"by another class. The arrow is labeled with the variable(s) "
-        //"through which the pointed class or struct is accessible.\n"
-		"<li>%  ȭǥ ø νϽ ø Ŭ Ÿ. "
-		" ȭǥ   νϽ ø Ű Ÿ.\n"
-        //"<li>%A yellow dashed arrow denotes a relation between a template instance and "
-        //"the template class it was instantiated from. The arrow is labeled with "
-        //"the template parameters of the instance.\n"
-        "</ul>\n";
+	  "Doxygen   ǥ  Դϴ.<p>\n"
+	  //"This page explains how to interpret the graphs that are generated "
+	  //"by doxygen.<p>\n"
+	  "  ϼ.\n"
+	  //"Consider the following example:\n"
+	  "\\code\n"
+	  "/*! Invisible class because of truncation */\n"
+	  "class Invisible { };\n\n"
+	  "/*! Truncated class, inheritance relation is hidden */\n"
+	  "class Truncated : public Invisible { };\n\n"
+	  "/* Class not documented with doxygen comments */\n"
+	  "class Undocumented { };\n\n"
+	  "/*! Class that is inherited using public inheritance */\n"
+	  "class PublicBase : public Truncated { };\n\n"
+	  "/*! A template class */\n"
+	  "template<class T> class Templ { };\n\n"
+	  "/*! Class that is inherited using protected inheritance */\n"
+	  "class ProtectedBase { };\n\n"
+	  "/*! Class that is inherited using private inheritance */\n"
+	  "class PrivateBase { };\n\n"
+	  "/*! Class that is used by the Inherited class */\n"
+	  "class Used { };\n\n"
+	  "/*! Super class that inherits a number of other classes */\n"
+	  "class Inherited : public PublicBase,\n"
+	  "                  protected ProtectedBase,\n"
+	  "                  private PrivateBase,\n"
+	  "                  public Undocumented\n"
+	  "                  public Templ<int>\n"
+	  "{\n"
+	  "  private:\n"
+	  "    Used *m_usedClass;\n"
+	  "};\n"
+	  "\\endcode\n"
+	  "  MAX_DOT_GRAPH_HEIGHT ÷װ 240 Ǿٸ  ׷  ̴."
+	  //"If the \\c MAX_DOT_GRAPH_HEIGHT tag in the configuration file "
+	  //"is set to 240 this will result in the following graph:"
+	  "<p><center><img src=\"graph_legend."+Config_getEnum("DOT_IMAGE_FORMAT")+"\"></center>\n"
+	  "<p>\n"
+	  "ڵ  Ѵ.\n"
+	  //"The boxes in the above graph have the following meaning:\n"
+	  "<ul>\n"
+	  "<li>% ڴ ׷  ü Ŭ Ѵ.\n"
+	  //"<li>%A filled black box represents the struct or class for which the "
+	  //"graph is generated.\n"
+	  "<li>%ε ڴ ȭ ü Ŭ ǥѴ.\n"
+	  //"<li>%A box with a black border denotes a documented struct or class.\n"
+	  "<li>%ȸε ڴ ȭ  ü Ŭ ǥѴ.\n"
+	  //"<li>%A box with a grey border denotes an undocumented struct or class.\n"
+	  "<li>%ε ڴ  /containment 踦   ȭ ü Ŭ Ÿ. "
+	  " ȿ   ׷ ©.\n"
+	  //"<li>%A box with a red border denotes a documented struct or class for"
+	  //"which not all inheritance/containment relations are shown. %A graph is "
+	  //"truncated if it does not fit within the specified boundaries.\n"
+	  "</ul>\n"
+	  "ȭǥ  Ѵ.\n"
+	  //"The arrows have the following meaning:\n"
+	  "<ul>\n"
+	  "<li>%ο Ķ ȭǥ  Ŭ public Ӱ踦 Ÿ.\n"
+	  //"<li>%A dark blue arrow is used to visualize a public inheritance "
+	  //"relation between two classes.\n"
+	  "<li>%ο  ȭǥ protected Ӱ踦 Ÿ.\n"
+	  //"<li>%A dark green arrow is used for protected inheritance.\n"
+	  "<li>%ο  ȭǥ private Ӱ踦 Ÿ.\n"
+	  //"<li>%A dark red arrow is used for private inheritance.\n"
+	  "<li>% ֻ ȭǥ Ŭ  ԵǴ  Ŭ Ÿ. "
+	  " ȭǥ     Ÿ.\n"
+	  //"<li>%A purple dashed arrow is used if a class is contained or used "
+	  //"by another class. The arrow is labeled with the variable(s) "
+	  //"through which the pointed class or struct is accessible.\n"
+	  "<li>%  ȭǥ ø νϽ ø Ŭ Ÿ. "
+	  " ȭǥ   νϽ ø Ű Ÿ.\n"
+	  //"<li>%A yellow dashed arrow denotes a relation between a template instance and "
+	  //"the template class it was instantiated from. The arrow is labeled with "
+	  //"the template parameters of the instance.\n"
+	  "</ul>\n";
     }
     /*! text for the link to the legend page */
     virtual QCString trLegend()
-    {
+      {
         return "";
     }
     
@@ -1155,65 +1094,54 @@ class TranslatorKorean : public TranslatorAdapter_1_3_9
     /*! Used as a section header for IDL properties */
     virtual QCString trProperties()
     {
-        return "properties"; // TODO: Need to be translated. -ryk11/22/01.
+        return "Ӽ";
     }
     /*! Used as a section header for IDL property documentation */
     virtual QCString trPropertyDocumentation()
     {
-        return "property ȭ"; // TODO: Need to be translated. -ryk11/22/01.
+        return "Ӽ ȭ";
     }
 
 //////////////////////////////////////////////////////////////////////////
 // new since 1.2.4
 //////////////////////////////////////////////////////////////////////////
 
-    /*! Used for Java interfaces in the summary section of Java packages */
-    virtual QCString trInterfaces()
-    {
-        return "̽"; // TODO: Need to be translated. -ryk11/22/01.
-    }
     /*! Used for Java classes in the summary section of Java packages */
     virtual QCString trClasses()
     {
       if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
       {
-          return " "; // TODO: Need to be translated. -ryk11/22/01.
+          return " ";
       }
       else
       {
-          return "Ŭ"; // TODO: Need to be translated. -ryk11/22/01.
+          return "Ŭ";
       }
     }
     /*! Used as the title of a Java package */
     virtual QCString trPackage(const char *name)
     {
-        return (QCString)"Ű "+name; // TODO: Need to be translated. -ryk11/22/01.
+        return (QCString)"Ű "+name;
     }
     /*! Title of the package index page */
     virtual QCString trPackageList()
     {
-        return "Ű "; // TODO: Need to be translated. -ryk11/22/01.
+        return "Ű ";
     }
     /*! The description of the package index page */
     virtual QCString trPackageListDescription()
     {
-		//Here are the packages with brief descriptions (if available):"; // TODO: Need to be translated. -ryk11/22/01.
         return "    Ű̴.";
     }
     /*! The link name in the Quick links header for each page */
     virtual QCString trPackages()
     {
-        return "Ű"; // TODO: Need to be translated. -ryk11/22/01.
-    }
-    /*! Used as a chapter title for Latex & RTF output */
-    virtual QCString trPackageDocumentation()
-    {
-        return "Ű ȭ"; // TODO: Need to be translated. -ryk11/22/01.
+        return "Ű";
     }
     /*! Text shown before a multi-line define */
     virtual QCString trDefineValue()
     {
-        return ":"; // TODO: Need to be translated. -ryk11/22/01.
+        return ":";
     }
     
 //////////////////////////////////////////////////////////////////////////
@@ -1223,12 +1151,12 @@ class TranslatorKorean : public TranslatorAdapter_1_3_9
     /*! Used as a marker that is put before a \\bug item */
     virtual QCString trBug()
     {
-        return ""; // TODO: Need to be translated. -ryk11/22/01.
+        return "";
     }
     /*! Used as the header of the bug list */
     virtual QCString trBugList()
     {
-        return " "; // TODO: Need to be translated. -ryk11/22/01.
+        return " ";
     }
 
 //////////////////////////////////////////////////////////////////////////
@@ -1277,29 +1205,29 @@ class TranslatorKorean : public TranslatorAdapter_1_3_9
     /*! Used as header RTF general index */
     virtual QCString trRTFGeneralIndex()
     {
-        return "ε"; // TODO: Need to be translated. -ryk11/22/01.
+        return "ε";
     }
    
     /*! This is used for translation of the word that will possibly
      *  be followed by a single name or by a list of names 
      *  of the category.
      */
-    virtual QCString trClass(bool first_capital, bool singular)
+    virtual QCString trClass(bool, bool singular)
     {
-      QCString result((first_capital ? "Ŭ" : "Ŭ"));
+      QCString result("Ŭ");
       if (!singular)  result+="";
-      return result;  // TODO: Need to be translated. -ryk11/22/01.
+      return result;
     }
 
     /*! This is used for translation of the word that will possibly
      *  be followed by a single name or by a list of names 
      *  of the category.
      */
-    virtual QCString trFile(bool first_capital, bool singular)
+    virtual QCString trFile(bool, bool singular)
     {
-      QCString result((first_capital ? "" : ""));
+      QCString result("");
       if (!singular)  result+="";
-      return result;  // TODO: Need to be translated. -ryk11/22/01.
+      return result;
     }
 
     /*! This is used for translation of the word that will possibly
@@ -1317,22 +1245,22 @@ class TranslatorKorean : public TranslatorAdapter_1_3_9
      *  be followed by a single name or by a list of names 
      *  of the category.
      */
-    virtual QCString trGroup(bool first_capital, bool singular)
+    virtual QCString trGroup(bool, bool singular)
     {
-      QCString result((first_capital ? "׷" : "׷"));
+      QCString result("׷");
       if (!singular)  result+="";
-      return result;  // TODO: Need to be translated. -ryk11/22/01.
+      return result;
     }
 
     /*! This is used for translation of the word that will possibly
      *  be followed by a single name or by a list of names 
      *  of the category.
      */
-    virtual QCString trPage(bool first_capital, bool singular)
+    virtual QCString trPage(bool, bool singular)
     {
-      QCString result((first_capital ? "" : ""));
+      QCString result("");
       if (!singular)  result+="";
-      return result;  // TODO: Need to be translated. -ryk11/22/01.
+      return result;
     }
 
     /*! This is used for translation of the word that will possibly
@@ -1343,20 +1271,9 @@ class TranslatorKorean : public TranslatorAdapter_1_3_9
     {
       QCString result((first_capital ? "" : ""));
       if (!singular)  result+="";
-      return result;  // TODO: Need to be translated. -ryk11/22/01.
+      return result;
     }
    
-    /*! This is used for translation of the word that will possibly
-     *  be followed by a single name or by a list of names 
-     *  of the category.
-     */
-    virtual QCString trField(bool first_capital, bool singular)
-    {
-      QCString result((first_capital ? "ʵ" : "ʵ"));
-      if (!singular)  result+="";
-      return result;  // TODO: Need to be translated. -ryk11/22/01.
-    }
-
     /*! This is used for translation of the word that will possibly
      *  be followed by a single name or by a list of names 
      *  of the category.
@@ -1365,7 +1282,7 @@ class TranslatorKorean : public TranslatorAdapter_1_3_9
     { 
       QCString result((first_capital ? "Global" : "global"));
       if (!singular)  result+="s";
-      return result;  // TODO: Need to be translated. -ryk11/22/01.
+      return result;
     }
 
 //////////////////////////////////////////////////////////////////////////
@@ -1374,11 +1291,11 @@ class TranslatorKorean : public TranslatorAdapter_1_3_9
 
     /*! This text is generated when the \\author command is used and
      *  for the author section in man pages. */
-    virtual QCString trAuthor(bool first_capital, bool singular)
+    virtual QCString trAuthor(bool, bool singular)
     {
-      QCString result((first_capital ? "ۼ" : "ۼ"));
+      QCString result("ۼ");
       if (!singular)  result+="";
-      return result;  // TODO: Need to be translated. -ryk11/22/01.
+      return result;
     }
 
 //////////////////////////////////////////////////////////////////////////
@@ -1389,7 +1306,7 @@ class TranslatorKorean : public TranslatorAdapter_1_3_9
      */
     virtual QCString trReferences()
     {
-        return ""; // TODO: Need to be translated. -ryk11/22/01.
+        return "";
     }
 
 //////////////////////////////////////////////////////////////////////////
@@ -1401,8 +1318,7 @@ class TranslatorKorean : public TranslatorAdapter_1_3_9
      */
     virtual QCString trImplementedFromList(int numEntries)
     {
-      //return "Implements "+trWriteList(numEntries)+".";
-	  return trWriteList(numEntries)+" .";
+      return trWriteList(numEntries)+" .";
     }
 
     /*! used in member documentation blocks to produce a list of
@@ -1410,8 +1326,7 @@ class TranslatorKorean : public TranslatorAdapter_1_3_9
      */
     virtual QCString trImplementedInList(int numEntries)
     {
-      //return "Implemented in "+trWriteList(numEntries)+".";
-	  return trWriteList(numEntries)+" Ǿ.";
+      return trWriteList(numEntries)+" Ǿ.";
     }
 
 //////////////////////////////////////////////////////////////////////////
@@ -1463,35 +1378,35 @@ class TranslatorKorean : public TranslatorAdapter_1_3_9
      */
     virtual QCString trPackageTypes()
     {
-        return "Ű ŸԵ"; //"Package Types";
+      return "Ű ŸԵ";
     }
     /*! Used as a heading for a list of Java class functions with package 
      * scope. 
      */
     virtual QCString trPackageMembers()
     {
-        return "Ű Լ"; //"Package Functions";
+      return "Ű Լ";
     }
     /*! Used as a heading for a list of static Java class functions with 
      *  package scope.
      */
     virtual QCString trStaticPackageMembers()
     {
-        return " Ű Լ"; //"Static Package Functions";
+      return " Ű Լ";
     }
     /*! Used as a heading for a list of Java class variables with package 
      * scope.
      */
     virtual QCString trPackageAttribs()
     {
-        return "Ű Ӽ"; //"Package Attributes";
+      return "Ű Ӽ";
     }
     /*! Used as a heading for a list of static Java class variables with 
      * package scope.
      */
     virtual QCString trStaticPackageAttribs()
     {
-        return " Ű Ӽ"; //"Static Package Attributes";
+      return " Ű Ӽ";
     }
     
 //////////////////////////////////////////////////////////////////////////
@@ -1509,7 +1424,6 @@ class TranslatorKorean : public TranslatorAdapter_1_3_9
     virtual QCString trCallGraph()
     {
         return "  Լ  ȣ ׷Դϴ:";
-        //"Here is the call graph for this function:";
     }
 
 //////////////////////////////////////////////////////////////////////////
@@ -1543,20 +1457,20 @@ class TranslatorKorean : public TranslatorAdapter_1_3_9
     {
         if (numDocuments==0)
         {
-            //return "Sorry, no documents matching your query.";
-            return "˼մϴ. ǿ ġϴ  ϴ.";
+	  //return "Sorry, no documents matching your query.";
+	  return "˼մϴ. ǿ ġϴ  ϴ.";
         }
         else if (numDocuments==1)
         {
-            //return "Found <b>1</b> document matching your query.";
-            return "ǿ ġϴ <b>1</b>  ãҽϴ.";
+	  //return "Found <b>1</b> document matching your query.";
+	  return "ǿ ġϴ <b>1</b>  ãҽϴ.";
         }
         else
         {
-            //return "Found <b>$num</b> documents matching your query. "
-            //    "Showing best matches first.";
-            return "ǿ ġϴ <b>$num</b>  ãҽϴ. "
-                "ó    ġϴ Դϴ.";
+	  //return "Found <b>$num</b> documents matching your query. "
+	  //    "Showing best matches first.";
+	  return "ǿ ġϴ <b>$num</b>  ãҽϴ. "
+	    "ó    ġϴ Դϴ.";
         }
     }
     /*! This string is put before the list of matched words, for each search 
@@ -1620,13 +1534,27 @@ class TranslatorKorean : public TranslatorAdapter_1_3_9
      */
     virtual QCString trDir(bool /*first_capital*/, bool /*singular*/)
     { 
-      // QCString result((first_capital ? "Director" : "director"));
-      // if (singular) result+="y"; else result+="ies";
-      
-      // return result; 
       return "";
     }
 
+
+//////////////////////////////////////////////////////////////////////////
+// new since 1.4.1
+//////////////////////////////////////////////////////////////////////////
+
+    /*! This text is added to the documentation when the \\overload command
+     *  is used for a overloaded function.
+     */
+    virtual QCString trOverloadText()
+    {
+      return "̰   Ǵ ε  Լ̴, "
+	" ƱԸƮ(argument) װ Ҷ  Լ ٸ.";
+
+    }
+
+
 };
 
 #endif
+
+
