@@ -2,7 +2,7 @@
  *
  * 
  *
- * Copyright (C) 1997-2004 by Dimitri van Heesch.
+ * Copyright (C) 1997-2005 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -1537,9 +1537,10 @@ class TranslatorPolish : public Translator
      *  and the fact that it is sorted alphabetically per level
      */
     virtual QCString trDirDescription()
-    { return "Ta struktura katalogw jest posortowana jest z grubsza, "
+    { 
+      return "Ta struktura katalogw jest posortowana jest z grubsza, "
              "cho nie cakowicie, alfabetycznie:";
-        }
+    }
 
     /*! This returns the title of a directory page. The name of the
      *  directory is passed via \a dirName.
@@ -1556,6 +1557,19 @@ class TranslatorPolish : public Translator
       if (! singular) result+="i";
       return result; 
     }
+
+//////////////////////////////////////////////////////////////////////////
+// new since 1.4.1
+//////////////////////////////////////////////////////////////////////////
+
+    /*! This text is added to the documentation when the \\overload command
+     *  is used for a overloaded function.
+     */
+    virtual QCString trOverloadText()
+    {
+      return "To jest metoda przeciona, udostpniona dla wygody. "
+             "Rni si od powyszej metody tylko zestawem akceptowanych argumentw.";               
+    }
 };
 
 #endif
