@@ -2,7 +2,7 @@
  *
  *
  *
- * Copyright (C) 1997-2002 by Dimitri van Heesch.
+ * Copyright (C) 1997-2005 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby
@@ -23,7 +23,7 @@
 #ifndef TRANSLATOR_SK_H
 #define TRANSLATOR_SK_H
 
-class TranslatorSlovak : public Translator
+class TranslatorSlovak : public TranslatorAdapter_1_2_18
 {
   private:
 	/*! The Decode() inline assumes the source written in the
@@ -263,7 +263,7 @@ class TranslatorSlovak : public Translator
 
 	  result += "s odkazmi na ";
 
-	  if (extractAll)
+	  if (!extractAll)
 	  {
 		if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
 		{
@@ -629,6 +629,8 @@ class TranslatorSlovak : public Translator
 		case ClassDef::Struct:	   result+="truktry "; break;
 		case ClassDef::Union:	   result+="unionu "; break;
 		case ClassDef::Interface:  result+="rozhrania "; break;
+		case ClassDef::Protocol:   result+="protocol "; break; // translate me!
+		case ClassDef::Category:   result+="category "; break; // translate me!
 		case ClassDef::Exception:  result+="vnimky "; break;
 	  }
 	  result+=clName;
@@ -799,6 +801,8 @@ class TranslatorSlovak : public Translator
 		case ClassDef::Struct:	   result+="tto truktru (struct)"; break;
 		case ClassDef::Union:	   result+="tento union"; break;
 		case ClassDef::Interface:  result+="toto rozhranie"; break;
+		case ClassDef::Protocol:   result+="protocol"; break; // translate me!
+		case ClassDef::Category:   result+="category"; break; // translate me!
 		case ClassDef::Exception:  result+="tto vnimku"; break;
 	  }
 	  result+=" bola generovan z ";
