@@ -2,7 +2,7 @@
  *
  * 
  *
- * Copyright (C) 1997-2004 by Dimitri van Heesch.
+ * Copyright (C) 1997-2005 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -20,7 +20,7 @@
 #ifndef TRANSLATOR_UA_H
 #define TRANSLATOR_UA_H
 
-class TranslatorUkrainian : public TranslatorAdapter_1_2_11
+class TranslatorUkrainian : public TranslatorAdapter_1_4_1
 {
   private:
     /*! The Decode() inline assumes the source written in the 
@@ -622,8 +622,8 @@ class TranslatorUkrainian : public TranslatorAdapter_1_2_11
           case ClassDef::Struct: result+=""; break;
           case ClassDef::Union:  result+="'"; break;
           case ClassDef::Interface:  result+=""; break;
-          case ClassDef::Protocol:   result+="protocol"; break; // translate me!
-          case ClassDef::Category:   result+="category"; break; // translate me!
+          case ClassDef::Protocol:   result+=""; break;
+          case ClassDef::Category:   result+="Ҧ"; break;
           case ClassDef::Exception:  result+=""; break;
         }
       }
@@ -635,8 +635,8 @@ class TranslatorUkrainian : public TranslatorAdapter_1_2_11
           case ClassDef::Struct: result+=""; break;
           case ClassDef::Union:  result+="'"; break;
           case ClassDef::Interface:  result+=""; break;
-          case ClassDef::Protocol:   result+="protocol"; break; // translate me!
-          case ClassDef::Category:   result+="category"; break; // translate me!
+          case ClassDef::Protocol:   result+=""; break;
+          case ClassDef::Category:   result+="Ҧ"; break;
           case ClassDef::Exception:  result+=""; break;
         }
       }
@@ -800,10 +800,10 @@ class TranslatorUkrainian : public TranslatorAdapter_1_2_11
           if (single) result+=" "; else result+=" Ӧ";
           break;
         case ClassDef::Protocol:  
-          if (single) result+="protocol"; else result+="protocols"; // translate me!
+          if (single) result+=" "; else result+=" ̦";
           break; 
         case ClassDef::Category:
-          if (single) result+="category"; else result+="categories"; // translate me!
+          if (single) result+="æ Ҧ"; else result+=" Ҧ";
           break; 
         case ClassDef::Exception:
           if (single) result+=" "; else result+=" ˦";
@@ -1024,7 +1024,7 @@ class TranslatorUkrainian : public TranslatorAdapter_1_2_11
     }
     virtual QCString trInclByDepGraph()
     {
-      return decode(" , ˦   :");
+      return decode(" ̦, ˦   :");
     }
     virtual QCString trSince()
     /*??*/
@@ -1048,7 +1048,7 @@ class TranslatorUkrainian : public TranslatorAdapter_1_2_11
         ",    .<p>\n"
         "  :\n"
         "\\code\n"
-        "/*!   -  */\n"
+        "/*!    Ҧ */\n"
         "class Invisible { };\n\n"
         "/*!  , צ   */\n"
         "class Truncated : public Invisible { };\n\n"
@@ -1338,6 +1338,249 @@ class TranslatorUkrainian : public TranslatorAdapter_1_2_11
       if (!singular) result+="";
       return decode(result); 
     }
+
+//////////////////////////////////////////////////////////////////////////
+// new since 1.2.11
+//////////////////////////////////////////////////////////////////////////
+
+    /*! This text is put before the list of members referenced by a member
+     */
+    virtual QCString trReferences()
+    {
+      return "դ";
+    }
+
+//////////////////////////////////////////////////////////////////////////
+// new since 1.2.13
+//////////////////////////////////////////////////////////////////////////
+
+    /*! used in member documentation blocks to produce a list of 
+     *  members that are implemented by this one.
+     */
+    virtual QCString trImplementedFromList(int numEntries)
+    {
+      return "̦դ " + trWriteList(numEntries) + ".";
+    }
+
+    /*! used in member documentation blocks to produce a list of
+     *  all members that implement this abstract member.
+     */
+    virtual QCString trImplementedInList(int numEntries)
+    {
+      return "̦դ  " + trWriteList(numEntries) + ".";
+    }
+
+//////////////////////////////////////////////////////////////////////////
+// new since 1.2.16
+//////////////////////////////////////////////////////////////////////////
+
+    /*! used in RTF documentation as a heading for the Table
+     *  of Contents.
+     */
+    virtual QCString trRTFTableOfContents()
+    {
+      return "ͦ";
+    }
+
+//////////////////////////////////////////////////////////////////////////
+// new since 1.2.17
+//////////////////////////////////////////////////////////////////////////
+
+    /*! Used as the header of the list of item that have been 
+     *  flagged deprecated 
+     */
+    virtual QCString trDeprecatedList()
+    {
+      return "Ҧ̦ ";
+    }
+
+//////////////////////////////////////////////////////////////////////////
+// new since 1.2.18
+//////////////////////////////////////////////////////////////////////////
+
+    /*! Used as a header for declaration section of the events found in 
+     * a C# program
+     */
+    virtual QCString trEvents()
+    {
+      return "Ħ";
+    }
+
+    /*! Header used for the documentation section of a class' events. */
+    virtual QCString trEventDocumentation()
+    {
+      return "æ Ħ";
+    }
+
+//////////////////////////////////////////////////////////////////////////
+// new since 1.3
+//////////////////////////////////////////////////////////////////////////
+
+    /*! Used as a heading for a list of Java class types with package scope.
+     */
+    virtual QCString trPackageTypes()
+    { 
+      return " Ԧ";
+    }
+
+    /*! Used as a heading for a list of Java class functions with package 
+     * scope. 
+     */
+    virtual QCString trPackageMembers()
+    { 
+      return "æ Ԧ";
+    }
+
+    /*! Used as a heading for a list of static Java class functions with 
+     *  package scope.
+     */
+    virtual QCString trStaticPackageMembers()
+    { 
+      return "Φ æ Ԧ";
+    }
+    
+    /*! Used as a heading for a list of Java class variables with package 
+     * scope.
+     */
+    virtual QCString trPackageAttribs()
+    {
+      return " Ԧ";
+    }
+    
+    /*! Used as a heading for a list of static Java class variables with 
+     * package scope.
+     */
+    virtual QCString trStaticPackageAttribs()
+    {
+      return "Φ  Ԧ";
+    }
+    
+//////////////////////////////////////////////////////////////////////////
+// new since 1.3.1
+//////////////////////////////////////////////////////////////////////////
+
+    /*! Used in the quick index of a class/file/namespace member list page 
+     *  to link to the unfiltered list of all members.
+     */
+    virtual QCString trAll()
+    {
+      return "Ӧ";
+    }
+    /*! Put in front of the call graph for a function. */
+    virtual QCString trCallGraph()
+    {
+      return " Ӧ ˦ æ æ:";
+    }
+
+//////////////////////////////////////////////////////////////////////////
+// new since 1.3.3
+//////////////////////////////////////////////////////////////////////////
+
+    /*! When the search engine is enabled this text is put in the header 
+     *  of each page before the field where one can enter the text to search 
+     *  for. 
+     */
+    virtual QCString trSearchForIndex()
+    {
+      return "";
+    }
+    /*! This string is used as the title for the page listing the search
+     *  results.
+     */
+    virtual QCString trSearchResultsTitle()
+    {
+      return " ";
+    }
+    /*! This string is put just before listing the search results. The
+     *  text can be different depending on the number of documents found.
+     *  Inside the text you can put the special marker $num to insert
+     *  the number representing the actual number of search results.
+     *  The @a numDocuments parameter can be either 0, 1 or 2, where the 
+     *  value 2 represents 2 or more matches. HTML markup is allowed inside
+     *  the returned string.
+     */
+    virtual QCString trSearchResults(int numDocuments)
+    {
+      if (numDocuments==0)
+      {
+        return "  Ԧ צצ   .";
+      }
+      else if (numDocuments==1)
+      {
+        return "  <b>1</b>  צצ   .";
+      }
+      else 
+      {
+        return "  <b>$num</b> Ԧ צצ   . "
+	       "ݦ צצԦ  .";
+      }
+    }
+    /*! This string is put before the list of matched words, for each search 
+     *  result. What follows is the list of words that matched the query.
+     */
+    virtual QCString trSearchMatches()
+    {
+      return "צΦ:";
+    }
+
+//////////////////////////////////////////////////////////////////////////
+// new since 1.3.8
+//////////////////////////////////////////////////////////////////////////
+
+    /*! This is used in HTML as the title of page with source code for file filename
+     */
+    virtual QCString trSourceFile(QCString& filename)
+    {
+      return "  "+filename;
+    }
+
+//////////////////////////////////////////////////////////////////////////
+// new since 1.3.9
+//////////////////////////////////////////////////////////////////////////
+
+    /*! This is used as the name of the chapter containing the directory
+     *  hierarchy.
+     */
+    virtual QCString trDirIndex()
+    { return " Ǧ"; }
+
+    /*! This is used as the name of the chapter containing the documentation
+     *  of the directories.
+     */
+    virtual QCString trDirDocumentation()
+    { return "æ Ǧ"; }
+
+    /*! This is used as the title of the directory index and also in the
+     *  Quick links of a HTML page, to link to the directory hierarchy.
+     */
+    virtual QCString trDirectories()
+    { return ""; }
+
+    /*! This returns a sentences that introduces the directory hierarchy. 
+     *  and the fact that it is sorted alphabetically per level
+     */
+    virtual QCString trDirDescription()
+    { return " Ǧ   "
+	     " צ:";
+    }
+
+    /*! This returns the title of a directory page. The name of the
+     *  directory is passed via \a dirName.
+     */
+    virtual QCString trDirReference(const char *dirName)
+    { QCString result="צ  "; result+=dirName; return result; }
+
+    /*! This returns the word directory with or without starting capital
+     *  (\a first_capital) and in sigular or plural form (\a singular).
+     */
+    virtual QCString trDir(bool, bool singular)
+    { 
+      QCString result("");
+      if (!singular) result+="";
+      return result; 
+    }
+
 };
 
 #endif
+
