@@ -57,6 +57,7 @@ class Definition;
 class TextGeneratorIntf
 {
   public:
+    virtual ~TextGeneratorIntf() {}
     virtual void writeString(const char *,bool) const = 0;
     virtual void writeBreak() const = 0;
     virtual void writeLink(const char *extRef,const char *file,
@@ -67,6 +68,7 @@ class TextGeneratorIntf
 class TextGeneratorOLImpl : public TextGeneratorIntf
 {
   public:
+    virtual ~TextGeneratorOLImpl() {}
     TextGeneratorOLImpl(OutputDocInterface &od);
     void writeString(const char *s,bool keepSpaces) const;
     void writeBreak() const;
@@ -129,10 +131,12 @@ void generateFileRef(OutputDocInterface &od,const char *,
                              const char *linkTxt=0);
 void writePageRef(OutputDocInterface &od,const char *cn,const char *mn);
 
+#if 0
 bool matchArguments(ArgumentList *,ArgumentList *,
                            const char *cl=0,const char *ns=0,bool checkCV=TRUE,
                            NamespaceSDict *usingNamespaces=0,
                            SDict<Definition> *usingClasses=0);
+#endif
 bool matchArguments2(Definition *srcScope,FileDef *srcFileScope,ArgumentList *srcAl,
                      Definition *dstScope,FileDef *dstFileScope,ArgumentList *dstAl,
                      bool checkCV
@@ -155,7 +159,7 @@ QCString showFileDefMatches(const FileNameDict *fnDict,const char *n);
 int guessSection(const char *name);
 bool isId(char c);
 QCString removeRedundantWhiteSpace(const QCString &s);
-QCString argListToString(ArgumentList *al);
+QCString argListToString(ArgumentList *al,bool useCanonicalType=FALSE);
 QCString tempArgListToString(ArgumentList *al);
 QCString generateMarker(int id);
 void writeExample(OutputList &ol,ExampleSDict *el);
